@@ -15,7 +15,7 @@ require_once('include/ListView/ListView.php');
 require_once('modules/CustomView/CustomView.php');
 require_once('include/DatabaseUtil.php');
 
-checkFileAccess("modules/$currentModule/$currentModule.php");
+checkFileAccessForInclusion("modules/$currentModule/$currentModule.php");
 require_once("modules/$currentModule/$currentModule.php");
 
 $category = getParentTab();
