@@ -10,12 +10,6 @@
  * The Initial Developer of the Original Code is SugarCRM, Inc.
  * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
  * All Rights Reserved.
- * Contributor(s): www.crm-now.de translation to German
- ********************************************************************************/
-/*********************************************************************************
- * Description:  Defines the German (Germany) language pack for the base application.
- * Contributor(s): 4net AG, Schoretshuebstr. 26 , CH-9015 St.Gallen
- *                 crm-now, Berlin, www.crm-now.com
  ********************************************************************************/
 $mod_strings = Array(
 'LBL_MODULE_NAME'=>'Benutzer',
@@ -649,7 +643,7 @@ $mod_strings = Array(
 
 'LBL_ENTER_PROFILE'=>'Profilnamen eingeben',
 'TITLE_USER_DOCUMENT'=>'Dokument ohne Namen',
-'TITLE_VTIGER_CRM_5'=>'crm-now/PS',
+'TITLE_VTIGER_CRM_5'=>'crm',
 'ROLE_DRAG_ERR_MSG'=>'Sie können keine übergeordnete Rolle unter eine untergeordnete Rolle verschieben.',
 
 'LBL_NOTIFICATION_ACTIVITY'=>'automatische Benachrichtigung',
@@ -684,5 +678,118 @@ $mod_strings = Array(
 'Asterisk Configuration' => 'Asterisk Konfiguration',
 'Asterisk Extension' => 'Asterisk Erweiterung',
 ' Receive Incoming Calls' => 'empfange eingehende Anrufe',
+
+// Added for Create Custom Fields 
+'LBL_USER_CUSTOMFIELDS_DESCRIPTION' => 'Erstellen Sie benutzerdefinierte Felder für Users ',
+'LBL_USER_CUSTOMFIELDS' => 'Benutzerdefinierte Felder für das Users-Modul',
+
+'LBL_CURRENCY_CONFIGURATION'=> 'Währungseinstellungen',
+
+'Time Zone'=>'Zeitzone',
+'Language'=>'Sprache',
+'Theme'=>'Theme',
+'Decimal Separator'=>'Dezimaltrennzeichen',
+'Symbol Placement'=>'Position des Währungssymbols',
+'Digit Grouping Pattern'=>'Muster für Zahlengruppierungen',
+'Digit Grouping Separator'=>'Trennzeichen für Zahlengruppierungen',
+
+//Time zones-Dont change any value
+'Kwajalein' => '(UTC-12:00) Internationale Datumsgrenze (Western)',
+'Pacific/Midway' => '(UTC-11:00) Koordinierte Weltzeit-11',
+'Pacific/Samoa' => '(UTC-11:00) Samoa',
+'Pacific/Honolulu' => '(UTC-10:00) Hawaii',
+'America/Anchorage' => '(UTC-09:00) Alaska',
+'America/Los_Angeles' => '(UTC-08:00) Pazifik Zeit (USA &amp; Canada)',
+'America/Tijuana' => '(UTC-08:00) Niederkalifornien',
+'America/Denver' => '(UTC-07:00) Mountain Zeit (USA &amp; Canada)',
+'America/Chihuahua' => '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
+'America/Mazatlan' => '(UTC-07:00) Mazatlan',
+'America/Phoenix' => '(UTC-07:00) Arizona',
+'America/Regina' => '(UTC-06:00) Saskatchewan',
+'America/Tegucigalpa' => '(UTC-06:00) Mittelamerika',
+'America/Chicago' => '(UTC-06:00) Central Zeit (USA &amp; Canada)',
+'America/Mexico_City' => '(UTC-06:00) Mexico-Stadt',
+'America/Monterrey' => '(UTC-06:00) Monterrey',
+'America/New_York' => '(UTC-05:00) Eastern Zeit (USA &amp; Canada)',
+'America/Bogota' => '(UTC-05:00) Bogota, Lima, Quito',
+'America/Lima' => '(UTC-05:00) Lima',
+'America/Rio_Branco' => '(UTC-05:00) Rio Branco',
+'America/Indiana/Indianapolis' => '(UTC-05:00) Indiana (Ost)',
+'America/Caracas' => '(UTC-04:30) Caracas',
+'America/Halifax' => '(UTC-04:00) Atlantic (Kanada)',
+'America/Manaus' => '(UTC-04:00) Manaus',
+'America/Santiago' => '(UTC-04:00) Santiago',
+'America/La_Paz' => '(UTC-04:00) La Paz',
+'America/Cuiaba' => '(UTC-04:00) Cuiaba',
+'America/Asuncion' => '(UTC-04:00) Asuncion',
+'America/St_Johns' => '(UTC-03:30) Neufundland',
+'America/Argentina/Buenos_Aires' => '(UTC-03:00) Buenos Aires',
+'America/Sao_Paulo' => '(UTC-03:00) Brasilia',
+'America/Godthab' => '(UTC-03:00) Grönland',
+'America/Montevideo' => '(UTC-03:00) Montevideo',
+'Atlantic/South_Georgia' => '(UTC-02:00) Mittelatlantik',
+'Atlantic/Azores' => '(UTC-01:00) Azoren',
+'Atlantic/Cape_Verde' => '(UTC-01:00) Kap Verde',
+'Europe/London' => '(UTC) London, Edinburgh, Dublin, Lisbon',
+'UTC' => '(UTC) Koordinierte Weltzeit',
+'Africa/Monrovia' => '(UTC) Monrovia, Reykjavik',
+'Africa/Casablanca' => '(UTC) Casablanca',
+'Europe/Belgrade' => '(UTC+01:00) Belgrad, Bratislava, Budapest, Ljubljana, Prag',
+'Europe/Sarajevo' => '(UTC+01:00) Sarajevo, Skopje, Warschau, Zagreb',
+'Europe/Brussels' => '(UTC+01:00) Brüssel, Kopenhagen, Madrid, Paris',
+'Africa/Algiers' => '(UTC+01:00) West-Zentralafrika',
+'Europe/Amsterdam' => '(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Wien',
+'Europe/Minsk' => '(UTC+02:00) Minsk',
+'Africa/Cairo' => '(UTC+02:00) Kairo',
+'Europe/Helsinki' => '(UTC+02:00) Helsinki, Riga, Sofia, Tallinn, Wilna',
+'Europe/Athens' => '(UTC+02:00) Athen, Bukarest',
+'Europe/Istanbul' => '(UTC+02:00) Istanbul',
+'Asia/Jerusalem' => '(UTC+02:00) Jerusalem',
+'Asia/Amman' => '(UTC+02:00) Amman',
+'Asia/Beirut' => '(UTC+02:00) Beirut',
+'Africa/Windhoek' => '(UTC+02:00) Windhoek',
+'Africa/Harare' => '(UTC+02:00) Harare',
+'Asia/Kuwait' => '(UTC+03:00) Kuwait, Riad',
+'Asia/Baghdad' => '(UTC+03:00) Bagdad',
+'Africa/Nairobi' => '(UTC+03:00) Nairobi',
+'Asia/Tehran' => '(UTC+03:30) Teheran',
+'Asia/Tbilisi' => '(UTC+04:00) Tbilisi',
+'Europe/Moscow' => '(UTC+04:00) Moskau, Wolgograd',
+'Asia/Muscat' => '(UTC+04:00) Abu Dhabi, Muskat',
+'Asia/Baku' => '(UTC+04:00) Baku',
+'Asia/Yerevan' => '(UTC+04:00) Yerevan',
+'Asia/Karachi' => '(UTC+05:00) Islamabad, Karatschi',
+'Asia/Tashkent' => '(UTC+05:00) Taschkent',
+'Asia/Kolkata' => '(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi',
+'Asia/Colombo' => '(UTC+05:30) Sri Jayawardenepura',
+'Asia/Katmandu' => '(UTC+05:45) Kathmandu',
+'Asia/Dhaka' => '(UTC+06:00) Dakka',
+'Asia/Almaty' => '(UTC+06:00) Almaty',
+'Asia/Yekaterinburg' => '(UTC+06:00) Jekaterinburg',
+'Asia/Rangoon' => '(UTC+06:30) Yangon (Rangun)',
+'Asia/Novosibirsk' => '(UTC+07:00) Nowosibirsk',
+'Asia/Bangkok' => '(UTC+07:00) Bangkok, Jakarta',
+'Asia/Brunei' => '(UTC+08:00) Peking, Chongqing, Hongkong, Urumchi',
+'Asia/Krasnoyarsk' => '(UTC+08:00) Krasnojarsk',
+'Asia/Ulaanbaatar' => '(UTC+08:00) Ulan-Bator',
+'Asia/Kuala_Lumpur' => '(UTC+08:00) Kuala Lumpur, Sinapur',
+'Asia/Taipei' => '(UTC+08:00) Taipeh',
+'Australia/Perth' => '(UTC+08:00) Perth',
+'Asia/Irkutsk' => '(UTC+09:00) Irkutsk',
+'Asia/Seoul' => '(UTC+09:00) Seoul',
+'Asia/Tokyo' => '(UTC+09:00) Tokio',
+'Australia/Darwin' => '(UTC+09:30) Darwin',
+'Australia/Adelaide' => '(UTC+09:30) Adelaide',
+'Australia/Canberra' => '(UTC+10:00) Canberra, Melbourne, Sydney',
+'Australia/Brisbane' => '(UTC+10:00) Brisbane',
+'Australia/Hobart' => '(UTC+10:00) Hobart',
+'Asia/Vladivostok' => '(UTC+10:00) Vladivostok',
+'Pacific/Guam' => '(UTC+10:00) Guam, Port Moresby',
+'Asia/Yakutsk' => '(UTC+10:00) Jakutsk',
+'Pacific/Fiji' => '(UTC+12:00) Fidschi',
+'Asia/Kamchatka' => '(UTC+12:00) Kamchatka',
+'Pacific/Auckland' => '(UTC+12:00) Auckland',
+'Asia/Magadan' => '(UTC+12:00) Magadan',
+'Pacific/Tongatapu' => '(UTC+13:00) Nukualofa',
 );
 ?>
\ No newline at end of file
