@@ -115,7 +115,7 @@ $mod_strings = Array(
 'ERR_ENTER_OLD_PASSWORD'=>'Por favor, introduzca su contraseña actual.',
 'ERR_ENTER_NEW_PASSWORD'=>'Por favor, introduzca su nueva contraseña.',
 'ERR_ENTER_CONFIRMATION_PASSWORD'=>'Por favor, confirme su nueva contraseña.',
-'ERR_REENTER_PASSWORDS'=>'Por favor, vuelva a introducir sus contraseñas. Los valores de \\\\\"Nueva Contraseña\\\\\" y \\\\\"Confirmar Contraseña\\\\\" no coinciden.',
+'ERR_REENTER_PASSWORDS'=>"Por favor, vuelva a introducir sus contraseñas. Los valores de 'Nueva Contraseña' y 'Confirmar Contraseña' no coinciden.",
 'ERR_INVALID_PASSWORD'=>'Debe especificar un nombre de usuario y contraseña válidos.',
 'ERR_PASSWORD_CHANGE_FAILED_1'=>'El Cambio de contraseña ha fallado para ',
 'ERR_PASSWORD_CHANGE_FAILED_2'=>' Error. La nueva contraseña debe ser fijada.',
@@ -417,16 +417,16 @@ $mod_strings = Array(
 
 'INVENTORYNOTIFICATION'=>'Notificaciones de Inventario',
 'LBL_INVENTORY_NOTIFICATIONS'=>'Editar Notificaciones de Inventario',
-'LBL_INV_NOT_DESC'=>'Listado de las notificaciones que se envían a los proveedores cuando durante la creación de un presupuesto, pedido o factura, no hay cantidad suficiente de producto .',
+'LBL_INV_NOT_DESC'=>'Listado de las notificaciones que se envían a los proveedores cuando durante la creación de un presupuesto, orden de venta o factura, no hay cantidad suficiente de producto .',
 
 'InvoiceNotification'=>'Notificación de stock de producto bajo durante la generación de una factura',
-'InvoiceNotificationDescription'=>'Si durante la Factura el stock del producto almacenado es menor que la cantidad demandada en el Pedido, se enviará esta notificación al responsable del producto',
+'InvoiceNotificationDescription'=>'Si durante la Factura el stock del producto almacenado es menor que la cantidad demandada en la orden de venta, se enviará esta notificación al responsable del producto',
 
 'QuoteNotification'=>'Notificación de stock de producto bajo durante la generación de un presupuesto',
-'QuoteNotificationDescription'=>'Si durante el Presupuesto el stock del producto almacenado es menor que la cantidad demandada en el Pedido, se enviará esta notificación al responsable del producto',
+'QuoteNotificationDescription'=>'Si durante el Presupuesto el stock del producto almacenado es menor que la cantidad demandada en la orden de venta, se enviará esta notificación al responsable del producto',
 
-'SalesOrderNotification'=>'Notificación de stock de producto bajo durante la generación de un Pedido',
-'SalesOrderNotificationDescription'=>'Si durante el Pedido el stock del producto almacenado es menor que la cantidad demandada en el Pedido, se enviará esta notificación al responsable del producto',
+'SalesOrderNotification'=>'Notificación de stock de producto bajo durante la generación de una orden de venta',
+'SalesOrderNotificationDescription'=>'Si durante la orden de venta el stock del producto almacenado es menor que la cantidad demandada en la orden de venta, se enviará esta notificación al responsable del producto',
 
 //New addition for 4.2 GA
 'LBL_USER_FIELDS'=>'Campos del Usuario',
@@ -458,8 +458,8 @@ $mod_strings = Array(
 'LBL_VENDOR_FIELD_ACCESS'=>'Acceso a los campos de Proveedores',
 'LBL_PB_FIELD_ACCESS'=>'Acceso a los campos de Tarifas',
 'LBL_QUOTE_FIELD_ACCESS'=>'Acceso a los campos de Presupuestos',
-'LBL_PO_FIELD_ACCESS'=>'Acceso a los campos de Órdenes de Compra',
-'LBL_SO_FIELD_ACCESS'=>'Acceso a los campos de Pedidos',
+'LBL_PO_FIELD_ACCESS'=>'Acceso a los campos de Ordenes de Compra',
+'LBL_SO_FIELD_ACCESS'=>'Acceso a los campos de Ordenes de Venta',
 'LBL_INVOICE_FIELD_ACCESS'=>'Acceso a los campos de Facturas',
 
 //given for calendar color for an user user
@@ -477,10 +477,10 @@ $mod_strings = Array(
 'HLT'=>'Partes Principales',
 'OLV'=>'Principales Actividades Abiertas',
 'GRT'=>'Principales Tareas del Grupo',
-'OLTSO'=>'Principales Pedidos',
+'OLTSO'=>'Principales Ordenes de Venta',
 'ILTI'=>'Principales Facturas',
 'HDB'=>'Página de Inicio de los Indicadores',
-'OLTPO'=>'Principales Órdenes de Compra',
+'OLTPO'=>'Principales Ordenes de Compra',
 'LTFAQ'=>'Mis Últimas FAQs',
 'UA'=>'Próximas Actividades',
 'PA'=>'Actividades Pendientes',
@@ -544,7 +544,7 @@ $mod_strings = Array(
 'Currency'=>'Moneda',
 'Title'=>'Cargo',
 'Office Phone'=>'Tel. Oficina',
-'Department'=>'Departmento',
+'Department'=>'Departamento',
 'Mobile'=>'Tel. Móvil',
 'Reports To'=>'Informa a',
 'Other Phone'=>'Tel. Directo',
@@ -688,6 +688,111 @@ $mod_strings = Array(
 'Asterisk Extension' => 'Extensión Asterisk',
 ' Receive Incoming Calls' => 'Recibir Llamadas Entrantes',
 
+// Added for Create Custom Fields 
+'LBL_USER_CUSTOMFIELDS_DESCRIPTION' => 'Crear Campos Personalizados para Usuarios ',
+'LBL_USER_CUSTOMFIELDS' => 'Campos Personalizados de Usuarios',
+
+'LBL_CURRENCY_CONFIGURATION'=> 'Configuración Moneda',
+
+//Time zones-Dont change any value
+'Kwajalein' => '(UTC-12:00) International Date Line West',
+'Pacific/Midway' => '(UTC-11:00) Coordinated Universal Time-11',
+'Pacific/Samoa' => '(UTC-11:00) Samoa',
+'Pacific/Honolulu' => '(UTC-10:00) Hawaii',
+'America/Anchorage' => '(UTC-09:00) Alaska',
+'America/Los_Angeles' => '(UTC-08:00) Pacific Time (US &amp; Canada)',
+'America/Tijuana' => '(UTC-08:00) Tijuana, Baja California',
+'America/Denver' => '(UTC-07:00) Mountain Time (US &amp; Canada)',
+'America/Chihuahua' => '(UTC-07:00) Chihuahua, La Paz, Mazatlan',
+'America/Mazatlan' => '(UTC-07:00) Mazatlan',
+'America/Phoenix' => '(UTC-07:00) Arizona',
+'America/Regina' => '(UTC-06:00) Saskatchewan',
+'America/Tegucigalpa' => '(UTC-06:00) Central America',
+'America/Chicago' => '(UTC-06:00) Central Time (US &amp; Canada)',
+'America/Mexico_City' => '(UTC-06:00) Mexico City',
+'America/Monterrey' => '(UTC-06:00) Monterrey',
+'America/New_York' => '(UTC-05:00) Eastern Time (US &amp; Canada)',
+'America/Bogota' => '(UTC-05:00) Bogota, Lima, Quito',
+'America/Lima' => '(UTC-05:00) Lima',
+'America/Rio_Branco' => '(UTC-05:00) Rio Branco',
+'America/Indiana/Indianapolis' => '(UTC-05:00) Indiana (East)',
+'America/Caracas' => '(UTC-04:30) Caracas',
+'America/Halifax' => '(UTC-04:00) Atlantic Time (Canada)',
+'America/Manaus' => '(UTC-04:00) Manaus',
+'America/Santiago' => '(UTC-04:00) Santiago',
+'America/La_Paz' => '(UTC-04:00) La Paz',
+'America/Cuiaba' => '(UTC-04:00) Cuiaba',
+'America/Asuncion' => '(UTC-04:00) Asuncion',
+'America/St_Johns' => '(UTC-03:30) Newfoundland',
+'America/Argentina/Buenos_Aires' => '(UTC-03:00) Buenos Aires',
+'America/Sao_Paulo' => '(UTC-03:00) Brasilia',
+'America/Godthab' => '(UTC-03:00) Greenland',
+'America/Montevideo' => '(UTC-03:00) Montevideo',
+'Atlantic/South_Georgia' => '(UTC-02:00) Mid-Atlantic',
+'Atlantic/Azores' => '(UTC-01:00) Azores',
+'Atlantic/Cape_Verde' => '(UTC-01:00) Cape Verde Is.',
+'Europe/London' => '(UTC) London, Edinburgh, Dublin, Lisbon',
+'UTC' => '(UTC) Coordinated Universal Time, Greenwich Mean Time',
+'Africa/Monrovia' => '(UTC) Monrovia, Reykjavik',
+'Africa/Casablanca' => '(UTC) Casablanca',
+'Europe/Belgrade' => '(UTC+01:00) Belgrade, Bratislava, Budapest, Ljubljana, Prague',
+'Europe/Sarajevo' => '(UTC+01:00) Sarajevo, Skopje, Warsaw, Zagreb',
+'Europe/Brussels' => '(UTC+01:00) Brussels, Copenhagen, Madrid, Paris',
+'Africa/Algiers' => '(UTC+01:00) West Central Africa',
+'Europe/Amsterdam' => '(UTC+01:00) Amsterdam, Berlin, Bern, Rome, Stockholm, Vienna',
+'Europe/Minsk' => '(UTC+02:00) Minsk',
+'Africa/Cairo' => '(UTC+02:00) Cairo',
+'Europe/Helsinki' => '(UTC+02:00) Helsinki, Riga, Sofia, Tallinn, Vilnius',
+'Europe/Athens' => '(UTC+02:00) Athens, Bucharest',
+'Europe/Istanbul' => '(UTC+02:00) Istanbul',
+'Asia/Jerusalem' => '(UTC+02:00) Jerusalem',
+'Asia/Amman' => '(UTC+02:00) Amman',
+'Asia/Beirut' => '(UTC+02:00) Beirut',
+'Africa/Windhoek' => '(UTC+02:00) Windhoek',
+'Africa/Harare' => '(UTC+02:00) Harare',
+'Asia/Kuwait' => '(UTC+03:00) Kuwait, Riyadh',
+'Asia/Baghdad' => '(UTC+03:00) Baghdad',
+'Africa/Nairobi' => '(UTC+03:00) Nairobi',
+'Asia/Tehran' => '(UTC+03:30) Tehran',
+'Asia/Tbilisi' => '(UTC+04:00) Tbilisi',
+'Europe/Moscow' => '(UTC+04:00) Moscow, Volgograd',
+'Asia/Muscat' => '(UTC+04:00) Abu Dhabi, Muscat',
+'Asia/Baku' => '(UTC+04:00) Baku',
+'Asia/Yerevan' => '(UTC+04:00) Yerevan',
+'Asia/Karachi' => '(UTC+05:00) Islamabad, Karachi',
+'Asia/Tashkent' => '(UTC+05:00) Tashkent',
+'Asia/Kolkata' => '(UTC+05:30) Chennai, Kolkata, Mumbai, New Delhi',
+'Asia/Colombo' => '(UTC+05:30) Sri Jayawardenepura',
+'Asia/Katmandu' => '(UTC+05:45) Kathmandu',
+'Asia/Dhaka' => '(UTC+06:00) Dhaka',
+'Asia/Almaty' => '(UTC+06:00) Almaty',
+'Asia/Yekaterinburg' => '(UTC+06:00) Ekaterinburg',
+'Asia/Rangoon' => '(UTC+06:30) Yangon (Rangoon)',
+'Asia/Novosibirsk' => '(UTC+07:00) Novosibirsk',
+'Asia/Bangkok' => '(UTC+07:00) Bangkok, Jakarta',
+'Asia/Brunei' => '(UTC+08:00) Beijing, Chongqing, Hong Kong, Urumqi',
+'Asia/Krasnoyarsk' => '(UTC+08:00) Krasnoyarsk',
+'Asia/Ulaanbaatar' => '(UTC+08:00) Ulaan Bataar',
+'Asia/Kuala_Lumpur' => '(UTC+08:00) Kuala Lumpur, Singapore',
+'Asia/Taipei' => '(UTC+08:00) Taipei',
+'Australia/Perth' => '(UTC+08:00) Perth',
+'Asia/Irkutsk' => '(UTC+09:00) Irkutsk',
+'Asia/Seoul' => '(UTC+09:00) Seoul',
+'Asia/Tokyo' => '(UTC+09:00) Tokyo',
+'Australia/Darwin' => '(UTC+09:30) Darwin',
+'Australia/Adelaide' => '(UTC+09:30) Adelaide',
+'Australia/Canberra' => '(UTC+10:00) Canberra, Melbourne, Sydney',
+'Australia/Brisbane' => '(UTC+10:00) Brisbane',
+'Australia/Hobart' => '(UTC+10:00) Hobart',
+'Asia/Vladivostok' => '(UTC+10:00) Vladivostok',
+'Pacific/Guam' => '(UTC+10:00) Guam, Port Moresby',
+'Asia/Yakutsk' => '(UTC+10:00) Yakutsk',
+'Pacific/Fiji' => '(UTC+12:00) Fiji',
+'Asia/Kamchatka' => '(UTC+12:00) Kamchatka',
+'Pacific/Auckland' => '(UTC+12:00) Auckland',
+'Asia/Magadan' => '(UTC+12:00) Magadan',
+'Pacific/Tongatapu' => '(UTC+13:00) Nukualofa',
+
 );
 
 ?>
