@@ -93,7 +93,8 @@ class VtigerActorOperation extends WebserviceEntityOperation {
 		$success = $this->__create($elementType,$element);
 		if(!$success){
 			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
-				"Database error while performing required operation create");
+				vtws_getWebserviceTranslatedString('LBL_'.
+							WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 		return $this->retrieve(vtws_getId($this->meta->getEntityId(),$this->id));
 	}
@@ -116,7 +117,8 @@ class VtigerActorOperation extends WebserviceEntityOperation {
 		$transactionSuccessful = vtws_runQueryAsTransaction($query,array($id),$result);
 		if(!$transactionSuccessful){
 			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
-				"Database error while performing required operation");
+				vtws_getWebserviceTranslatedString('LBL_'.
+							WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 		$db = $this->pearDB;
 		if($result){
@@ -162,7 +164,8 @@ class VtigerActorOperation extends WebserviceEntityOperation {
 		$success = $this->__update($element,$ids[1]);
 		if(!$success){
 			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
-				"Database error while performing required operation");
+				vtws_getWebserviceTranslatedString('LBL_'.
+							WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 		return $this->retrieve(vtws_getId($this->meta->getEntityId(),$ids[1]));
 	}
@@ -199,7 +202,8 @@ class VtigerActorOperation extends WebserviceEntityOperation {
 		$success = $this->__revise($element,$ids[1]);
 		if(!$success){
 			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
-				"Database error while performing required operation");
+				vtws_getWebserviceTranslatedString('LBL_'.
+							WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 
 		return $this->retrieve(vtws_getId($this->meta->getEntityId(),$ids[1]));
@@ -220,7 +224,8 @@ class VtigerActorOperation extends WebserviceEntityOperation {
 		$success = $this->__delete($elemId);
 		if(!$success){
 			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
-				"Database error while performing required operation");
+				vtws_getWebserviceTranslatedString('LBL_'.
+							WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 		return array("status"=>"successful");
 	}
@@ -296,7 +301,9 @@ class VtigerActorOperation extends WebserviceEntityOperation {
 		$this->pearDB->completeTransaction();
 
 		if($error){
-			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,"Database error while performing required operation");
+			throw new WebServiceException(WebServiceErrorCode::$DATABASEQUERYERROR,
+					vtws_getWebserviceTranslatedString('LBL_'.
+							WebServiceErrorCode::$DATABASEQUERYERROR));
 		}
 
 		$noofrows = $this->pearDB->num_rows($result);
