@@ -68,7 +68,7 @@ abstract class WebserviceEntityOperation{
 			case 'reference': $typeDetails['refersTo'] = $webserviceField->getReferenceList();
 				break;
 			case 'multipicklist':
-			case 'picklist': $typeDetails["picklistValues"] = $this->getPicklistDetails($webserviceField);
+			case 'picklist': $typeDetails["picklistValues"] = $webserviceField->getPicklistDetails($webserviceField);
 				$typeDetails['defaultValue'] = $typeDetails["picklistValues"][0]['value'];
 				break;
 			case 'file': $maxUploadSize = 0;
@@ -92,7 +92,7 @@ abstract class WebserviceEntityOperation{
 	
 	function isEditable($webserviceField){
 		if(((int)$webserviceField->getDisplayType()) === 2 || strcasecmp($webserviceField->getFieldDataType(),"autogenerated")
-			===0 || strcasecmp($webserviceField->getFieldDataType(),"id")===0){
+			===0 || strcasecmp($webserviceField->getFieldDataType(),"id")===0 || $webserviceField->isReadOnly() == true){
 			return false;
 		}
 		//uitype 70 is vtiger generated fields, such as (of vtiger_crmentity table) createdtime
@@ -103,56 +103,6 @@ abstract class WebserviceEntityOperation{
 		return true;
 	}
 	
-	function getPicklistDetails($webserviceField){
-		$hardCodedPickListNames = array("hdntaxtype","email_flag");
-		$hardCodedPickListValues = array(
-				"hdntaxtype"=>array(
-					array("label"=>"Individual","value"=>"individual"),
-					array("label"=>"Group","value"=>"group")
-				),
-				"email_flag" => array(
-					array('label'=>'SAVED','value'=>'SAVED'),
-					array('label'=>'SENT','value' => 'SENT')
-				)
-			);
-		if(in_array(strtolower($webserviceField->getFieldName()),$hardCodedPickListNames)){
-			return $hardCodedPickListValues[strtolower($webserviceField->getFieldName())];
-		}
-		return $this->getPickListOptions($webserviceField->getFieldName());
-	}
-	
-	function getPickListOptions($fieldName){
-		
-		$default_charset = VTWS_PreserveGlobal::getGlobal('default_charset');
-		$options = array();
-		$sql = "select * from vtiger_picklist where name=?";
-		$result = $this->pearDB->pquery($sql,array($fieldName));
-		$numRows = $this->pearDB->num_rows($result);
-		if($numRows == 0){
-			$sql = "select * from vtiger_$fieldName";
-			$result = $this->pearDB->pquery($sql,array());
-			$numRows = $this->pearDB->num_rows($result);
-			for($i=0;$i<$numRows;++$i){
-				$elem = array();
-				$picklistValue = $this->pearDB->query_result($result,$i,$fieldName);
-				$picklistValue = html_entity_decode($picklistValue, ENT_QUOTES, $default_charset);
-				$elem["label"] = getTranslatedString($picklistValue,$this->getMeta()->getTabName());
-				$elem["value"] = $picklistValue;
-				array_push($options,$elem);
-			}
-		}else{
-			$details = getPickListValues($fieldName,$this->user->roleid);
-			for($i=0;$i<sizeof($details);++$i){
-				$elem = array();
-				$picklistValue = html_entity_decode($details[$i], ENT_QUOTES, $default_charset);
-				$elem["label"] = getTranslatedString($picklistValue,$this->getMeta()->getTabName());
-				$elem["value"] = $picklistValue;
-				array_push($options,$elem);
-			}
-		}
-		return $options;
-	}
-	
 	function getIdField($label){
 		return array('name'=>'id','label'=>$label,'mandatory'=>false,'type'=>'id','editable'=>false,'type'=>
 						array('name'=>'autogenerated'),'nullable'=>false,'default'=>"");
