@@ -6,7 +6,6 @@
   * The Initial Developer of the Original Code is vtiger.
   * Portions created by vtiger are Copyright (C) vtiger.
   * All Rights Reserved.
- * German translation provided by crm-now: www.crm-now.de
   ********************************************************************************/
 $app_strings = array (
 	'Groups'=>'Gruppen',
@@ -16,4 +15,11 @@ $app_strings = array (
 	'SINGLE_DocumentFolders'=>'Dokumentenverzeichnis',
 	'SINGLE_Currency'=>'Währung',
 );
+
+$webservice_strings = array(
+	'LBL_INVALID_OLD_PASSWORD' => 'Ungültige Angabe des alten Passwortes.',
+	'LBL_NEW_PASSWORD_MISMATCH' => "Die beiden Passwörter stimmen nicht überein.",
+	'LBL_DATABASE_QUERY_ERROR' => 'Ihre Anfrage konnte aufgrund eines Datenbankfehlers nicht verarbeitet werden.',
+	'LBL_CHANGE_PASSWORD_FAILURE' => 'Passwort konnte nicht geändert werden.Failed to change password',
+);
 ?>
\ No newline at end of file
