@@ -16,4 +16,12 @@ $app_strings = array (
 	'SINGLE_DocumentFolders'=>'Document Folder',
 	'SINGLE_Currency'=>'Currency',
 );
+
+$webservice_strings = array(
+	'LBL_INVALID_OLD_PASSWORD' => 'Invalid value given for old password.',
+	'LBL_NEW_PASSWORD_MISMATCH' => "New Password and confirm password don't match",
+	'LBL_DATABASE_QUERY_ERROR' => 'Database error while performing requested operation',
+	'LBL_CHANGE_PASSWORD_FAILURE' => 'Failed to change password',
+);
+
 ?>
\ No newline at end of file
