@@ -302,5 +302,13 @@
 				'LBL_ENTER_WINDOW_TITLE': 'Please enter Window Title.',
 				'LBL_SELECT_ONLY_FIELDS': 'Please select only two fields.',
 				'LBL_ENTER_RSS_URL':'Please enter RSS URL',
-				'LBL_ADD_HOME_WIDGET': 'Unable to add homestuff! Please try again'
+				'LBL_ADD_HOME_WIDGET': 'Unable to add homestuff! Please try again',
+				
+				'LBL_DEFAULT_VALUE_FOR_THIS_FIELD' : 'Default Value for this Field',
+
+				'RECIPIENTS_CANNOT_BE_EMPTY' : 'Selected Recipients cannot be empty',
+				'VALID_SCANNER_NAME' : 'Please enter a valid Scanner name (It should be only Characters and Numbers)',
+				'ERR_SAME_SOURCE_AND_TARGET' : 'Source field and Target field should not be same',
+				'ERR_ATLEAST_ONE_VALUE_FOR' : 'You need to select at least one value for',
+				'ERR_SELECT_MODULE_FOR_DEPENDENCY' : 'Please select a module to add Dependency'
 			};
