@@ -883,54 +883,6 @@ $combo->create_nonpicklist_tables();
 create_tab_data_file();
 create_parenttab_data_file();
 
-//to get the users lists
-$query = 'select id from vtiger_users';
-$result=$adb->pquery($query,array());
-
-//creating home page widgets
-$defaultWidgets = array(array('Top Accounts', 0, 'ALVT', 'Accounts'), 
-						array('Home Page Dashboard', 1, 'HDB', 'Dashboard'),
-						array('Top Potentials', 0, 'PLVT','Potentials'),
-						array('Top Quotes', 0,'QLTQ','Quotes'),
-						array('Key Metrics', 0,'CVLVT','NULL'),
-						array('Top Trouble Tickets', 0,'HLT','HelpDesk'),
-						array('Upcoming Activities', 0,'UA','Calendar'),
-						array('My Group Allocation', 1,'GRT','NULL'),
-						array('Top Sales Orders', 0,'OLTSO','SalesOrder'),
-						array('Top Invoices', 0,'ILTI','Invoice'),
-						array('My New Leads', 0,'MNL','Leads'),
-						array('Top Purchase Orders', 0,'OLTPO','PurchaseOrder'),
-						array('Pending Activities', 0,'PA','Calendar'),
-						array('My Recent FAQs', 0,'LTFAQ','Faq'),);
-
-$defaultWidgets = array_reverse($defaultWidgets);
-
-for($u=0;$u<$adb->num_rows($result);$u++){
-	$userid = $adb->query_result($result,$u,'id');
-	
-	for($i=0; $i<count($defaultWidgets); $i++){
-		$stuffid = $adb->getUniqueID("vtiger_homestuff");
-		$widgetTitle = $defaultWidgets[$i][0];
-		$visible = $defaultWidgets[$i][1];
-		$type = $defaultWidgets[$i][2];
-		$module = $defaultWidgets[$i][3];
-		$sequence = $i+1;
-		
-		$sql="insert into vtiger_homestuff values(?, ?, 'Default', ?, ?, ?)";
-		$res=$adb->pquery($sql,array($stuffid, $sequence, $userid, $visible, $widgetTitle));
-		
-		$sql="insert into vtiger_homedefault values($stuffid, '$type', 5, '$module')";
-		$adb->pquery($sql,array());
-	}
-	
-	$stuffid = $adb->getUniqueID("vtiger_homestuff");
-	$widgetTitle = "Tag Cloud";
-	$visible = 0;
-	$sequence = $i+1;
-	$sql="insert into vtiger_homestuff values(?, ?, 'Tag Cloud', ?, ?, ?)";
-	$res=$adb->pquery($sql,array($stuffid, $sequence, $userid, $visible, $widgetTitle));
-}
-
 // default report population
 require_once('modules/Reports/PopulateReports.php');
 
@@ -969,9 +921,16 @@ function registerEvents($adb) {
 
 	// Registering event for Recurring Invoices
 	$em->registerHandler('vtiger.entity.aftersave', 'modules/SalesOrder/RecurringInvoiceHandler.php', 'RecurringInvoiceHandler');
+
+	//Registering Entity Delta handler for before save and after save events of the record to track the field value changes
+	$em->registerHandler('vtiger.entity.beforesave', 'data/VTEntityDelta.php', 'VTEntityDelta');
+	$em->registerHandler('vtiger.entity.aftersave', 'data/VTEntityDelta.php', 'VTEntityDelta');
 	
 	// Workflow manager
-	$em->registerHandler('vtiger.entity.aftersave', 'modules/com_vtiger_workflow/VTEventHandler.inc', 'VTWorkflowEventHandler');
+	$dependentEventHandlers = array('VTEntityDelta');
+	$dependentEventHandlersJson = Zend_Json::encode($dependentEventHandlers);
+	$em->registerHandler('vtiger.entity.aftersave', 'modules/com_vtiger_workflow/VTEventHandler.inc', 'VTWorkflowEventHandler',
+								'',$dependentEventHandlersJson);
 	
 	//Registering events for On modify
 	$em->registerHandler('vtiger.entity.afterrestore', 'modules/com_vtiger_workflow/VTEventHandler.inc', 'VTWorkflowEventHandler');
@@ -1159,6 +1118,39 @@ function setFieldHelpInfo() {
 				'<br>When the same ticket is added to a Service Contract,'. 
 				'based on the Tracking Unit of the Service Contract,'.
 				'Used units is updated whenever a ticket is Closed.');
+
+	$usersModuleInstance = Vtiger_Module::getInstance('Users');
+	$field1 = Vtiger_Field::getInstance('currency_grouping_pattern', $usersModuleInstance);
+	$field2 = Vtiger_Field::getInstance('currency_decimal_separator', $usersModuleInstance);
+	$field3 = Vtiger_Field::getInstance('currency_grouping_separator', $usersModuleInstance);
+	$field4 = Vtiger_Field::getInstance('currency_symbol_placement', $usersModuleInstance);
+
+	$field1->setHelpInfo("<b>Currency - Digit Grouping Pattern</b> <br/><br/>".
+								"This pattern specifies the format in which the currency separator will be placed.");
+	$field2->setHelpInfo("<b>Currency - Decimal Separator</b> <br/><br/>".
+										"Decimal separator specifies the separator to be used to separate ".
+										"the fractional values from the whole number part. <br/>".
+										"<b>Eg:</b> <br/>".
+										". => 123.45 <br/>".
+										", => 123,45 <br/>".
+										"' => 123'45 <br/>".
+										"  => 123 45 <br/>".
+										"$ => 123$45 <br/>");
+	$field3->setHelpInfo("<b>Currency - Grouping Separator</b> <br/><br/>".
+										"Grouping separator specifies the separator to be used to group ".
+										"the whole number part into hundreds, thousands etc. <br/>".
+										"<b>Eg:</b> <br/>".
+										". => 123.456.789 <br/>".
+										", => 123,456,789 <br/>".
+										"' => 123'456'789 <br/>".
+										"  => 123 456 789 <br/>".
+										"$ => 123$456$789 <br/>");
+	$field4->setHelpInfo("<b>Currency - Symbol Placement</b> <br/><br/>".
+										"Symbol Placement allows you to configure the position of the ".
+										"currency symbol with respect to the currency value.<br/>".
+										"<b>Eg:</b> <br/>".
+										"$1.0 => $123,456,789.50 <br/>".
+										"1.0$ => 123,456,789.50$ <br/>");
 }
 
 ?>
