@@ -100,7 +100,8 @@ function gshow(argg1,type,startdate,enddate,starthr,startmin,startfmt,endhr,endm
 		{
 			for(var i=0;;i++){
 				if( document.EditView.activitytype[i].value == type){
-					document.EditView.activitytype[i].selected='yes';	
+					document.EditView.activitytype[i].selected='yes';
+					triggerOnChangeHandler(('activitytype'));
 					break;
 				}
 			}
@@ -220,227 +221,201 @@ function enableCalstarttime()
 	else	
 		document.SharingForm.start_hour.disabled = true;
 }
-function check_form()
-{
+function check_form() {
 	formSelectColumnString('inviteesid','selectedusers');
-        if(trim(document.EditView.subject.value) == "")
-        {
-                alert(alert_arr.MISSING_EVENT_NAME);
-                document.EditView.subject.focus()
-                return false;
-        }
-        else
-        {
-		if(document.EditView.record.value != '')
-                {
-                        document.EditView.mode.value = 'edit';
-                }
-		else
-		{
+	if(trim(document.EditView.subject.value) == "") {
+		alert(alert_arr.MISSING_EVENT_NAME);
+		document.EditView.subject.focus()
+		return false;
+	} else {
+		if(document.EditView.record.value != '') {
+			document.EditView.mode.value = 'edit';
+		} else {
 			document.EditView.mode.value = 'create';
 		}
 		starthour = parseInt(document.EditView.starthr.value,10);
-                startmin  = parseInt(document.EditView.startmin.value,10);
-                startformat = document.EditView.startfmt.value;
-                endhour = parseInt(document.EditView.endhr.value,10);
-                endmin  = parseInt(document.EditView.endmin.value,10);
-                endformat = document.EditView.endfmt.value;
+		startmin  = parseInt(document.EditView.startmin.value,10);
+		startformat = document.EditView.startfmt.value;
+		endhour = parseInt(document.EditView.endhr.value,10);
+		endmin  = parseInt(document.EditView.endmin.value,10);
+		endformat = document.EditView.endfmt.value;
 		followupformat = document.EditView.followup_startfmt.value;
-                followuphour = parseInt(document.EditView.followup_starthr.value,10);
-                followupmin = parseInt(document.EditView.followup_startmin.value,10);
-		if(startformat != '')
-		{
-			if(startformat == 'pm')
-			{
+		followuphour = parseInt(document.EditView.followup_starthr.value,10);
+		followupmin = parseInt(document.EditView.followup_startmin.value,10);
+		if(startformat != '') {
+			if(startformat == 'pm') {
 				if(starthour == 12)
 					starthour = 12;
 				else
 					starthour = starthour + 12;
-			}
-			else
-			{
+			} else {
 				if(starthour == 12)
-                                	starthour = 0;
+					starthour = 0;
 				else
 					starthour = starthour;
 			}
 		}
-		if(endformat != '')
-		{
-			if(endformat == 'pm')
-                        {
+		if(endformat != '') {
+			if(endformat == 'pm') {
 				if(endhour == 12)
-                                        endhour = 12;
-                                else
-                                        endhour = endhour + 12;
-                        }
-			else
-			{
+					endhour = 12;
+				else
+					endhour = endhour + 12;
+			} else {
 				if(endhour == 12)
 					endhour = 0;
 				else
 					endhour = endhour;
 			}
 		}
-		if(!dateValidate('date_start','Start date','OTH'))
-		{
+		if(!dateValidate('date_start','Start date','OTH')) {
 			return false;
 		}
-		if(!dateValidate('due_date','End date','OTH'))
-		{
+		if(!dateValidate('due_date','End date','OTH')) {
 			return false;
 		}
-		if(dateComparison('due_date','End date','date_start','Start date','GE'))
-		{
+		if(dateComparison('due_date','End date','date_start','Start date','GE')) {
 			var dateval1=getObj('date_start').value.replace(/^\s+/g, '').replace(/\s+$/g, '');
-        	var dateval2=getObj('due_date').value.replace(/^\s+/g, '').replace(/\s+$/g, '');
+			var dateval2=getObj('due_date').value.replace(/^\s+/g, '').replace(/\s+$/g, '');
 			var dateval3=getObj('followup_date').value.replace(/^\s+/g, '').replace(/\s+$/g, '');
 
-            var dateelements1=splitDateVal(dateval1)
-        	var dateelements2=splitDateVal(dateval2)
+			var dateelements1=splitDateVal(dateval1)
+			var dateelements2=splitDateVal(dateval2)
 			var dateelements3=splitDateVal(dateval3)
 
-            dd1=dateelements1[0]
-	        mm1=dateelements1[1]
-        	yyyy1=dateelements1[2]
+			dd1=dateelements1[0]
+			mm1=dateelements1[1]
+			yyyy1=dateelements1[2]
 
-            dd2=dateelements2[0]
-	        mm2=dateelements2[1]
-        	yyyy2=dateelements2[2]
+			dd2=dateelements2[0]
+			mm2=dateelements2[1]
+			yyyy2=dateelements2[2]
 
 			dd3=dateelements3[0]
-            mm3=dateelements3[1]
-            yyyy3=dateelements3[2]
+			mm3=dateelements3[1]
+			yyyy3=dateelements3[2]
 
-            var date1=new Date()
-	        var date2=new Date()
+			var date1=new Date()
+			var date2=new Date()
 			var date3=new Date()
 
-        	date1.setYear(yyyy1)
-            date1.setMonth(mm1-1)
-	        date1.setDate(dd1)
+			date1.setYear(yyyy1)
+			date1.setMonth(mm1-1)
+			date1.setDate(dd1)
 			date1.setHours(starthour)
 			date1.setMinutes(startmin)
 
-	        date2.setYear(yyyy2)
-            date2.setMonth(mm2-1)
-        	date2.setDate(dd2)
+			date2.setYear(yyyy2)
+			date2.setMonth(mm2-1)
+			date2.setDate(dd2)
 			date2.setHours(endhour)
 			date2.setMinutes(endmin)
 
 			date3.setYear(yyyy3)
-            date3.setMonth(mm3-1)
-            date3.setDate(dd3)
+			date3.setMonth(mm3-1)
+			date3.setDate(dd3)
  
 			diff_ms = Math.abs(date2.getTime()-date1.getTime())/(1000*60);
 			hour = Math.floor(diff_ms/(60));
 			minute = Math.floor(diff_ms % 60)
 			document.EditView.duration_hours.value = hour;
-            document.EditView.duration_minutes.value = minute;
+			document.EditView.duration_minutes.value = minute;
 			
-            event_starthour = _2digit(starthour);
-            event_startmin = _2digit(startmin);
-            event_endhour = _2digit(endhour);
-            event_endmin = _2digit(endmin);
-            document.EditView.time_start.value = event_starthour+':'+event_startmin;
-            document.EditView.time_end.value = event_endhour+':'+event_endmin;
+			event_starthour = _2digit(starthour);
+			event_startmin = _2digit(startmin);
+			event_endhour = _2digit(endhour);
+			event_endmin = _2digit(endmin);
+			document.EditView.time_start.value = event_starthour+':'+event_startmin;
+			document.EditView.time_end.value = event_endhour+':'+event_endmin;
 			// Added for Aydin Kurt-Elli requirement START -by Minnie
-            if (document.EditView.followup.checked == true && document.getElementById('date_table_thirdtd').style.display == 'block')
-            {
-                    if(!dateValidate('followup_date','Followup Date','OTH'))
-                    {
-                            return false;
-                    }
-                    if(followupformat != '')
-                    {
-                            if(followupformat == 'pm')
-                            {
-                                    if(followuphour == 12)
-                                            followuphour = 12;
-                                    else
-                                            followuphour = followuphour + 12;
-                            }
-                            else
-                            {
-                                    if(followuphour == 12)
-                                            followuphour = 0;
-                                    else
-                                            followuphour = followuphour;
-                            }
-                    }
+			if (document.EditView.followup.checked == true && 
+				document.getElementById('date_table_thirdtd').style.display == 'block') {
+				if(!dateValidate('followup_date','Followup Date','OTH')) {
+					return false;
+				}
+				if(followupformat != '') {
+					if(followupformat == 'pm') {
+						if(followuphour == 12)
+							followuphour = 12;
+						else
+							followuphour = followuphour + 12;
+					} else {
+						if(followuphour == 12)
+							followuphour = 0;
+						else
+							followuphour = followuphour;
+					}
+				}
 	
-					if ( compareDates(date3,'Followup Date',date2,'End Date','GE'))
-                    {
-                            if (date3 <= date2)
-                            {
-                                    if((followuphour*60+followupmin) <= (endhour*60+endmin))
-                                    {
-                                            alert(alert_arr.FOLLOWUPTIME_GREATER_THAN_STARTTIME);
-                                            document.EditView.followup_starthr.focus();
-                                            return false;
-                                    }
-                            }
-                    }
-                    else return false;
-                 //modified to set followup end date depends on the event or todo. If it is Event, the difference between followup start date and end date is 1hr. If it is todo then difference is 5mins.
-                    date3.setMinutes(followupmin);
-                    date3.setHours(followuphour);
-                    if(document.EditView.activitytype[0].checked == true)
-                    {
-                            date3.setMinutes(parseInt(date3.getMinutes(),10)+5);
-                    }
-                    if(document.EditView.activitytype[1].checked == true)
-                    {
-                            date3.setMinutes(parseInt(date3.getMinutes(),10)+60);
-                    }
-					var tempdate = getdispDate(date3);
+				if ( compareDates(date3,'Followup Date',date2,'End Date','GE')) {
+					if (date3 <= date2) {
+						if((followuphour*60+followupmin) <= (endhour*60+endmin)) {
+							alert(alert_arr.FOLLOWUPTIME_GREATER_THAN_STARTTIME);
+							document.EditView.followup_starthr.focus();
+							return false;
+						}
+					}
+				}
+				else return false;
+				//modified to set followup end date depends on the event or todo. If it is Event, the difference between followup start date and end date is 1hr. If it is todo then difference is 5mins.
+				date3.setMinutes(followupmin);
+				date3.setHours(followuphour);
+				if(document.EditView.activitytype[0].checked == true) {
+					date3.setMinutes(parseInt(date3.getMinutes(),10)+5);
+				}
+				if(document.EditView.activitytype[1].checked == true) {
+					date3.setMinutes(parseInt(date3.getMinutes(),10)+60);
+				}
+				var tempdate = getdispDate(date3);
 
-					followuphour = _2digit(followuphour);
-			        followupmin = _2digit(followupmin);
-					followupendhour = _2digit(date3.getHours());
-			        followupendmin = _2digit(date3.getMinutes());		
-			        document.EditView.followup_due_date.value = tempdate; 
-                    document.EditView.followup_time_start.value = followuphour+':'+followupmin;
-                    document.EditView.followup_time_end.value = followupendhour+':'+followupendmin;
-					//end
-            }
-            // Added for Aydin Kurt-Elli requirement END -by Minnie -->
+				followuphour = _2digit(followuphour);
+				followupmin = _2digit(followupmin);
+				followupendhour = _2digit(date3.getHours());
+				followupendmin = _2digit(date3.getMinutes());
+				document.EditView.followup_due_date.value = tempdate;
+				document.EditView.followup_time_start.value = followuphour+':'+followupmin;
+				document.EditView.followup_time_end.value = followupendhour+':'+followupendmin;
+			//end
+			}
+			// Added for Aydin Kurt-Elli requirement END -by Minnie -->
 
 			//added to avoid db error while giving characters in the repeat "every n no of day in month" text box
-                        if((getObj("recurringcheck")) && (document.EditView.recurringcheck.checked == true) && (document.EditView.recurringtype.value =="Monthly"))
-                        {
-				if((document.EditView.repeatMonth[0].checked == true) && ((parseInt(parseFloat(document.EditView.repeatMonth_date.value))!=document.EditView.repeatMonth_date.value) || document.EditView.repeatMonth_date.value=='' || parseInt(document.EditView.repeatMonth_date.value)>'31' || document.EditView.repeatMonth_date.value<='0'))
-                                {
-                                        alert(alert_arr.INVALID +' "'+document.EditView.repeatMonth_date.value+'" ');
-                                        document.EditView.repeatMonth_date.focus();
-                                        return false;
-                                }
-                        }
-                        //end
+			if((getObj("recurringcheck")) && (document.EditView.recurringcheck.checked == true) && 
+				(document.EditView.recurringtype.value =="Monthly")) {
+				if((document.EditView.repeatMonth[0].checked == true) && 
+					((parseInt(parseFloat(document.EditView.repeatMonth_date.value))!=
+						document.EditView.repeatMonth_date.value) ||
+					document.EditView.repeatMonth_date.value=='' ||
+					parseInt(document.EditView.repeatMonth_date.value)>'31' ||
+					document.EditView.repeatMonth_date.value<='0')) {
+					alert(alert_arr.INVALID +' "'+document.EditView.repeatMonth_date.value+'" ');
+					document.EditView.repeatMonth_date.focus();
+					return false;
+				}
+			}
+			//end
 
 
-                        //added to check Start Date & Time,if Activity Status is Planned.//start
-                        if(document.EditView.eventstatus.value == "Planned")
-                        {
-                                var chkdate=new Date()
+			//added to check Start Date & Time,if Activity Status is Planned.//start
+			if(document.EditView.eventstatus.value == "Planned") {
+				var chkdate=new Date()
 				chkdate.setMinutes(event_startmin)
 				chkdate.setHours(event_starthour)
-                                chkdate.setYear(yyyy1)
-                                chkdate.setMonth(mm1-1)
-                                chkdate.setDate(dd1)
+				chkdate.setYear(yyyy1)
+				chkdate.setMonth(mm1-1)
+				chkdate.setDate(dd1)
 				if(!comparestartdate(chkdate)) return false;
 
-                        }
+			}
 
 		}	
 		else
 			return false;
-		if(getObj("recurringcheck") && document.EditView.recurringcheck.checked == false)
-                {
-                        document.EditView.recurringtype.value = '--None--';
-                }
-                return true;
-        }
+		if(getObj("recurringcheck") && document.EditView.recurringcheck.checked == false) {
+			document.EditView.recurringtype.value = '--None--';
+		}
+		return true;
+	}
 }
 
 function task_check_form()
@@ -948,12 +923,14 @@ function delActivity(id,view,hour,day,month,year,subtab)
 {
 	if(subtab == 'event')
 	{
+		var users = document.getElementsByName('onlyforuser');
+		var onlyforuser = users[0].value;
 		var OptionData = $('view_Option').options[$('view_Option').selectedIndex].value;
          	new Ajax.Request(
 	                	'index.php',
 	                	{queue: {position: 'end', scope: 'command'},
 	                        	method: 'post',
-	                        	postBody: 'module=Users&action=massdelete&return_module=Calendar&return_action=ActivityAjax&idlist='+id+'&view='+view+'&hour='+hour+'&day='+day+'&month='+month+'&year='+year+'&type=activity_delete&viewOption='+OptionData+'&subtab=event&ajax=true',
+	                        	postBody: 'module=Users&action=massdelete&return_module=Calendar&return_action=ActivityAjax&idlist='+id+'&view='+view+'&hour='+hour+'&day='+day+'&month='+month+'&year='+year+'&type=activity_delete&viewOption='+OptionData+'&subtab=event&ajax=true&onlyforuser='+encodeURIComponent(onlyforuser),
 	                        	onComplete: function(response) {
 								if(OptionData == 'listview')
 								{
@@ -1229,6 +1206,7 @@ function calDuedatetime(type)
 			hour = _2digit(hour);
                         min = _2digit(min);
 			document.EditView.due_date.value = date;
+			document.EditView.calendar_repeat_limit_date.value = date;
 			document.EditView.endhr.value = hour;
 			document.EditView.endmin.value = min;
 			document.EditView.endfmt.value = fmt;
@@ -1240,10 +1218,10 @@ function calDuedatetime(type)
 		{
                         if(hour == 11)
                         {
-                                hour = 12; min = min; fmt = 'pm';
+                                hour = 12;min = min;fmt = 'pm';
                         }else if(hour == 12)
                         {
-                                hour = 1; min = min; fmt = 'am';
+                                hour = 1;min = min;fmt = 'am';
                         }
                         else hour = hour + 1;
 			hour = _2digit(hour);
@@ -1280,12 +1258,12 @@ function calDuedatetime(type)
                 {
                         if(hour == 11 && min == 55)
                         {
-                                hour = 12; min = 0; fmt = 'am';
+                                hour = 12;min = 0;fmt = 'am';
                                 date = tempdate;
                         }
 			else if(hour == 12 && min == 55)
 			{
-				hour = 1; min = 0; fmt = 'pm';
+				hour = 1;min = 0;fmt = 'pm';
 			}
                         else
                         {
@@ -1299,6 +1277,7 @@ function calDuedatetime(type)
 			hour = _2digit(hour);
                         min = _2digit(min);
                         document.EditView.due_date.value = date;
+						document.EditView.calendar_repeat_limit_date.value = date;
                         document.EditView.endhr.value = hour;
                         document.EditView.endmin.value = min;
                         document.EditView.endfmt.value = fmt;
@@ -1332,6 +1311,7 @@ function calDuedatetime(type)
 			hour = _2digit(hour);
                         min = _2digit(min);
                         document.EditView.due_date.value = date;
+						document.EditView.calendar_repeat_limit_date.value = date;
                         document.EditView.endhr.value = hour;
                         document.EditView.endmin.value = min;
                         document.EditView.endfmt.value = fmt;
@@ -1355,6 +1335,7 @@ function calDuedatetime(type)
 			hour = _2digit(hour);
                         min = _2digit(min);
                         document.EditView.due_date.value = date;
+						document.EditView.calendar_repeat_limit_date.value = date;
                         document.EditView.endhr.value = hour;
                         document.EditView.endmin.value = min;
 			document.EditView.followup_date.value = date;
