@@ -81,9 +81,10 @@ function getKeyMetrics($maxval,$calCnt)
 			$metricresult = $adb->query($metricsql);
 			if($metricresult)
 			{
-				$rowcount = $adb->fetch_array($metricresult);	
-				if(isset($rowcount))
-				{
+				if($metriclist['module'] == "Calendar") {
+					$metriclists[$key]['count'] = $adb->num_rows($metricresult);
+				} else {
+					$rowcount = $adb->fetch_array($metricresult);
 					$metriclists[$key]['count'] = $rowcount['count'];
 				}
 			}
