@@ -69,8 +69,8 @@ if($cvmodule != "") {
 	$startdate = $_REQUEST["startdate"];
 	$enddate = $_REQUEST["enddate"];
 	if($stdcriteria == "custom") {
-		$startdate = getDBInsertDateValue($startdate);
-		$enddate = getDBInsertDateValue($enddate);
+		$startdate = DateTimeField::convertToDBFormat($startdate);
+		$enddate = DateTimeField::convertToDBFormat($enddate);
 	}
 	$std_filter_list["startdate"] = $startdate;
 	$std_filter_list["enddate"]=$enddate;
@@ -79,29 +79,18 @@ if($cvmodule != "") {
 	//<<<<<<<standardfilters>>>>>>>>>
 
 	//<<<<<<<advancedfilter>>>>>>>>>
-	for ($i=0;$i<count($allKeys);$i++) {
-	   $string = substr($allKeys[$i], 0, 4);
-		if($string == "fcol" && $_REQUEST[$allKeys[$i]] !== null &&
-				$_REQUEST[$allKeys[$i]] !== '') {
-           	$adv_filter_col[] = $_REQUEST[$allKeys[$i]];
-   	   }
-	}
-	for ($i=0;$i<count($allKeys);$i++) {
-	   $string = substr($allKeys[$i], 0, 3);
-		if($string == "fop" && $_REQUEST[$allKeys[$i]] !== null &&
-				$_REQUEST[$allKeys[$i]] !== '') {
-           	$adv_filter_option[] = $_REQUEST[$allKeys[$i]];
-   	   }
-	}
-	for ($i=0;$i<count($allKeys);$i++) {
-   	   $string = substr($allKeys[$i], 0, 4);
-		if($string == "fval"  && $_REQUEST[$allKeys[$i]] !== null &&
-				$_REQUEST[$allKeys[$i]] !== '') {
-		   $adv_filter_value[] = trim(vtlib_purify($_REQUEST[$allKeys[$i]]));
-   	   }
-	}
+	$json = new Zend_Json();
+	
+	$advft_criteria = $_REQUEST['advft_criteria'];
+	$advft_criteria = $json->decode($advft_criteria);
+	
+	$advft_criteria_groups = $_REQUEST['advft_criteria_groups'];
+	$advft_criteria_groups = $json->decode($advft_criteria_groups);
 	//<<<<<<<advancedfilter>>>>>>>>
 
+	$moduleHandler = vtws_getModuleHandlerFromName($cvmodule,$current_user);
+	$moduleMeta = $moduleHandler->getMeta();
+	$moduleFields = $moduleMeta->getModuleFields();
 	if(!$cvid) {
 		$genCVid = $adb->getUniqueID("vtiger_customview");
 		if($genCVid != "") {
@@ -129,7 +118,7 @@ if($cvmodule != "") {
 			}
 			
 			$log->info("CustomView :: Save :: setdefault upated successfully");
-			
+
 			if($customviewresult) {
 				if(isset($columnslist)) {
 					for($i=0;$i<count($columnslist);$i++) {
@@ -144,24 +133,72 @@ if($cvmodule != "") {
 						$stdfilterresult = $adb->pquery($stdfiltersql, $stdfilterparams);
 						$log->info("CustomView :: Save :: vtiger_cvstdfilter created successfully");
 					}
-					for($i=0;$i<count($adv_filter_col);$i++) {
-						$col = explode(":",$adv_filter_col[$i]);
-						$temp_val = explode(",",$adv_filter_value[$i]);
-						if($col[4] == 'D' || ($col[4] == 'T' && $col[1] != 'time_start' && $col[1] != 'time_end') || $col[4] == 'DT') {
+					
+					foreach($advft_criteria as $column_index => $column_condition) {
+								
+						if(empty($column_condition)) continue;
+								
+						$adv_filter_column = $column_condition["columnname"];
+						$adv_filter_comparator = $column_condition["comparator"];
+						$adv_filter_value = $column_condition["value"];
+						$adv_filter_column_condition = $column_condition["columncondition"];
+						$adv_filter_groupid = $column_condition["groupid"];
+					
+						$column_info = explode(":",$adv_filter_column);
+						
+						$fieldName = $column_info[2];
+						$fieldObj = $moduleFields[$fieldName];
+						$fieldType = $fieldObj->getFieldDataType();
+
+						if($fieldType == 'currency') {
+							if($fieldObj->getUIType() == '71') {
+								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value, null, true);
+							} else {
+								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value);
+							}
+						}
+
+						$temp_val = explode(",",$adv_filter_value);
+						if(($fieldType == 'date' || ($fieldType == 'time' && $fieldName != 'time_start' && $fieldName != 'time_end') || ($fieldType == 'datetime')) && ($fieldType != '' && $adv_filter_value != '' )) {
 							$val = Array();
 							for($x=0;$x<count($temp_val);$x++) {
-								//if date and time given then we have to convert the date and leave the time as it is, if date only given then temp_time value will be empty
-								list($temp_date,$temp_time) = explode(" ",$temp_val[$x]);
-								$temp_date = getDBInsertDateValue(trim($temp_date));
-								if(trim($temp_time) != '')
-									$temp_date .= ' '.$temp_time;
-								$val[$x] = $temp_date;
+								//if date and time given then we have to convert the date and
+								//leave the time as it is, if date only given then temp_time
+								//value will be empty
+								if(trim($temp_val[$x]) != '') {
+									$date = new DateTimeField(trim($temp_val[$x]));
+									if($fieldType == 'date') {
+										$val[$x] = DateTimeField::convertToUserFormat(
+												trim($temp_val[$x]));
+									} elseif($fieldType == 'datetime') {
+										$val[$x] = $date->getDBInsertDateTimeValue();
+									} else {
+										$val[$x] = $date->getDBInsertTimeValue();
+									}
+								}
 							}
-							$adv_filter_value[$i] = implode(", ",$val);
+							$adv_filter_value = implode(",",$val);
 						}
-						$advfiltersql = "INSERT INTO vtiger_cvadvfilter(cvid,columnindex,columnname,comparator,value) VALUES (?,?,?,?,?)";
-						$advfilterparams = array($genCVid, $i, $adv_filter_col[$i], $adv_filter_option[$i], $adv_filter_value[$i]);
-						$advfilterresult = $adb->pquery($advfiltersql, $advfilterparams);
+		
+						$irelcriteriasql = "INSERT INTO vtiger_cvadvfilter(cvid,columnindex,columnname,comparator,value,groupid,column_condition) values (?,?,?,?,?,?,?)";
+						$irelcriteriaresult = $adb->pquery($irelcriteriasql, array($genCVid, $column_index, $adv_filter_column, $adv_filter_comparator, $adv_filter_value, $adv_filter_groupid, $adv_filter_column_condition));
+					
+						// Update the condition expression for the group to which the condition column belongs
+						$groupConditionExpression = '';
+						if(!empty($advft_criteria_groups[$adv_filter_groupid]["conditionexpression"])) {
+							$groupConditionExpression = $advft_criteria_groups[$adv_filter_groupid]["conditionexpression"];
+						}
+						$groupConditionExpression = $groupConditionExpression .' '. $column_index .' '. $adv_filter_column_condition;
+						$advft_criteria_groups[$adv_filter_groupid]["conditionexpression"] = $groupConditionExpression;
+					}
+					
+					foreach($advft_criteria_groups as $group_index => $group_condition_info) {				
+								
+						if(empty($group_condition_info)) continue;
+						if(empty($group_condition_info["conditionexpression"])) continue; // Case when the group doesn't have any column criteria
+											
+						$irelcriteriagroupsql = "insert into vtiger_cvadvfilter_grouping(groupid,cvid,group_condition,condition_expression) values (?,?,?,?)";
+						$irelcriteriagroupresult = $adb->pquery($irelcriteriagroupsql, array($group_index, $genCVid, $group_condition_info["groupcondition"], $group_condition_info["conditionexpression"]));
 					}
 					$log->info("CustomView :: Save :: vtiger_cvadvfilter created successfully");
 				}
@@ -202,7 +239,11 @@ if($cvmodule != "") {
 	
 			$deletesql = "DELETE FROM vtiger_cvadvfilter WHERE cvid = ?";
 			$deleteresult = $adb->pquery($deletesql, array($cvid));
-			$log->info("CustomView :: Save :: vtiger_cvcolumnlist,cvstdfilter,cvadvfilter deleted successfully before update".$genCVid);
+	
+			$deletesql = "DELETE FROM vtiger_cvadvfilter_grouping WHERE cvid = ?";
+			$deleteresult = $adb->pquery($deletesql, array($cvid));
+			
+			$log->info("CustomView :: Save :: vtiger_cvcolumnlist,cvstdfilter,cvadvfilter,cvadvfilter_grouping deleted successfully before update".$genCVid);
 	
 			$genCVid = $cvid;
 			if($updatecvresult) {
@@ -219,24 +260,73 @@ if($cvmodule != "") {
 						$stdfilterresult = $adb->pquery($stdfiltersql, $stdfilterparams);
 						$log->info("CustomView :: Save :: vtiger_cvstdfilter update successfully".$genCVid);
 					}
-					for($i=0;$i<count($adv_filter_col);$i++) {
-						$col = explode(":",$adv_filter_col[$i]);
-						$temp_val = explode(",",$adv_filter_value[$i]);
-						if($col[4] == 'D' || ($col[4] == 'T' && $col[1] != 'time_start' && $col[1] != 'time_end') || $col[4] == 'DT') {
+					
+					foreach($advft_criteria as $column_index => $column_condition) {
+								
+						if(empty($column_condition)) continue;
+								
+						$adv_filter_column = $column_condition["columnname"];
+						$adv_filter_comparator = $column_condition["comparator"];
+						$adv_filter_value = $column_condition["value"];
+						$adv_filter_column_condition = $column_condition["columncondition"];
+						$adv_filter_groupid = $column_condition["groupid"];
+					
+						$column_info = explode(":",$adv_filter_column);
+						
+						$fieldName = $column_info[2];
+						$fieldObj = $moduleFields[$fieldName];
+						$fieldType = $fieldObj->getFieldDataType();
+
+						if($fieldType == 'currency') {
+							// Some of the currency fields like Unit Price, Total, Sub-total etc of Inventory modules, do not need currency conversion
+							if($fieldObj->getUIType() == '72') {
+								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value, null, true);
+							} else {
+								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value);
+							}
+						}
+
+						$temp_val = explode(",",$adv_filter_value);
+						if(($fieldType == 'date' || ($fieldType == 'time' && $fieldName != 'time_start' && $fieldName != 'time_end') || ($fieldType == 'datetime')) && ($fieldType != '' && $adv_filter_value != '' )) {
 							$val = Array();
 							for($x=0;$x<count($temp_val);$x++) {
-								//if date and time given then we have to convert the date and leave the time as it is, if date only given then temp_time value will be empty
-								list($temp_date,$temp_time) = explode(" ",$temp_val[$x]);
-								$temp_date = getDBInsertDateValue(trim($temp_date));
-								if(trim($temp_time) != '')
-									$temp_date .= ' '.$temp_time;
-								$val[$x] = $temp_date;
+								//if date and time given then we have to convert the date and
+								//leave the time as it is, if date only given then temp_time
+								//value will be empty
+								if(trim($temp_val[$x]) != '') {
+									$date = new DateTimeField(trim($temp_val[$x]));
+									if($fieldType == 'date') {
+										$val[$x] = DateTimeField::convertToUserFormat(
+												trim($temp_val[$x]));
+									} elseif($fieldType == 'datetime') {
+										$val[$x] = $date->getDBInsertDateTimeValue();
+									} else {
+										$val[$x] = $date->getDBInsertTimeValue();
+									}
+								}
 							}
-							$adv_filter_value[$i] = implode(", ",$val);	
+							$adv_filter_value = implode(",",$val);
 						}
-						$advfiltersql = "INSERT INTO vtiger_cvadvfilter (cvid,columnindex,columnname,comparator,value) VALUES (?,?,?,?,?)";
-						$advfilterparams = array($genCVid, $i, $adv_filter_col[$i], $adv_filter_option[$i], $adv_filter_value[$i]);
-						$advfilterresult = $adb->pquery($advfiltersql, $advfilterparams);
+		
+						$irelcriteriasql = "INSERT INTO vtiger_cvadvfilter(cvid,columnindex,columnname,comparator,value,groupid,column_condition) values (?,?,?,?,?,?,?)";
+						$irelcriteriaresult = $adb->pquery($irelcriteriasql, array($genCVid, $column_index, $adv_filter_column, $adv_filter_comparator, $adv_filter_value, $adv_filter_groupid, $adv_filter_column_condition));
+					
+						// Update the condition expression for the group to which the condition column belongs
+						$groupConditionExpression = '';
+						if(!empty($advft_criteria_groups[$adv_filter_groupid]["conditionexpression"])) {
+							$groupConditionExpression = $advft_criteria_groups[$adv_filter_groupid]["conditionexpression"];
+						}
+						$groupConditionExpression = $groupConditionExpression .' '. $column_index .' '. $adv_filter_column_condition;
+						$advft_criteria_groups[$adv_filter_groupid]["conditionexpression"] = $groupConditionExpression;
+					}
+					
+					foreach($advft_criteria_groups as $group_index => $group_condition_info) {				
+								
+						if(empty($group_condition_info)) continue;
+						if(empty($group_condition_info["conditionexpression"])) continue; // Case when the group doesn't have any column criteria
+											
+						$irelcriteriagroupsql = "insert into vtiger_cvadvfilter_grouping(groupid,cvid,group_condition,condition_expression) values (?,?,?,?)";
+						$irelcriteriagroupresult = $adb->pquery($irelcriteriagroupsql, array($group_index, $genCVid, $group_condition_info["groupcondition"], $group_condition_info["conditionexpression"]));
 					}
 					$log->info("CustomView :: Save :: vtiger_cvadvfilter update successfully".$cvid);
 				}
