@@ -314,8 +314,8 @@ $smarty->assign("FIELDNAMES", $fieldnames);
 $smarty->assign("ALPHABETICAL", $alphabetical);
 $smarty->assign("NAVIGATION", $navigationOutput);
 $smarty->assign("RECORD_COUNTS", $record_string);
-
-$smarty->assign("IS_ADMIN",$current_user->is_admin);
+$adminuser = is_admin($current_user);
+$smarty->assign("IS_ADMIN",$adminuser);
 
 $check_button = Button_Check($module);
 $smarty->assign("CHECK", $check_button);
