@@ -103,7 +103,7 @@ if(isset($_REQUEST['module']) && $_REQUEST['module'] != ''){
 	// vtlib customization: Hook added to enable import for un-mapped modules
 	$module = $_REQUEST['module'];	
 	if($current_bean_type == null) {
-		checkFileAccess("modules/$module/$module.php");
+		checkFileAccessForInclusion("modules/$module/$module.php");
 		require_once("modules/$module/$module.php");
 		$current_bean_type = $module;
 		$callInitImport = true;		
