@@ -215,7 +215,7 @@ else
 
 	// vtlib customization: Hook provide to include custom modules
 	$module = $_REQUEST['modulename'];
-	checkFileAccess("modules/$module/$module.php");
+	checkFileAccessForInclusion("modules/$module/$module.php");
 	require_once("modules/$module/$module.php");
 	$import_modules_array[$module] = $module;
 	// END
