@@ -141,7 +141,7 @@ $mod_strings = Array(
 'LBL_FINISHED'=>'Finished',
 'LBL_UNDO_LAST_IMPORT'=>'Undo Last Import',
 
-'LBL_SUCCESS_1' => 'No. of Records Successfully Imported : ',
+'LBL_SUCCESS_1' => 'No. of Records Successfully Imported/Updated : ',
 'LBL_SKIPPED_1' => 'No. of Records Skipped as they were missing one or more required fields : ',
 
 //Added for patch2 - Products Import Notes
@@ -190,54 +190,14 @@ $mod_strings = Array(
 
 'LBL_DELIMITER' => 'Delimiter:',
 'LBL_FORMAT' => 'Format:',
+'LBL_MAX_FILE_SIZE' => ' is the max allowed filesize',
+
+'LBL_MERGE_FIELDS_DUPLICATE' => 'Merge Fields For Duplicate Import Records',
+'Customer Portal Login Details' => 'Customer Portal Login Details',
 );
 
-/*$mod_list_strings = Array(
-	"id"=>"Contact ID"
-	,"first_name"=>"First Name"
-	,"last_name"=>"Last Name"
-	,"salutation"=>"Salutation"
-	,"lead_source"=>"Lead Source"
-	,"birthdate"=>"Lead Source"
-	,"do_not_call"=>"Do Not Call"
-	,"email_opt_out"=>"Email Opt Out"
-	,"primary_address_street_2"=>"Primary Address Street 2"
-	,"primary_address_street_3"=>"Primary Address Street 3"
-	,"alt_address_street_2"=>"Other Address Street 2"
-	,"alt_address_street_3"=>"Other Address Street 3"
-	,"full_name"=>"Full Name"
-	,"account_name"=>"Account Name"
-	,"account_id"=>"Account ID"
-	,"title"=>"Title"
-	,"department"=>"Department"
-	,"birthdate"=>"Birthdate"
-	,"do_not_call"=>"Do Not Call"
-	,"phone_home"=>"Phone (Home)"
-	,"phone_mobile"=>"Phone (Mobile)"
-	,"phone_work"=>"Phone (Work)"
-	,"phone_other"=>"Phone (Other)"
-	,"phone_fax"=>"Fax"
-	,"email1"=>"Email"
-	,"email2"=>"Email (Other)"
-	,"yahoo_id"=>"Yahoo! ID"
-	,"assistant"=>"Assistant"
-	,"assistant_phone"=>"Assistant Phone"
-	,"primary_address_street"=>"Primary Address Street"
-	,"primary_address_city"=>"Primary Address City"
-	,"primary_address_state"=>"Primary Address State"
-	,"primary_address_postalcode"=>"Primary Address Postalcode"
-	,"primary_address_country"=>"Primary Address Country"
-	,"alt_address_street"=>"Other Address Street"
-	,"alt_address_city"=>"Other Address City"
-	,"alt_address_state"=>"Other Address State"
-	,"alt_address_postalcode"=>"Other Address Postalcode"
-	,"alt_address_country"=>"Other Address Country"
-	,"description"=>"Description"
-
-	),*/
 $mod_list_strings = Array(
 'contacts_import_fields' => Array(
-	//"id"=>"Contact ID"
 	"firstname"=>"First Name"
 	,"lastname"=>"Last Name"
 	,"salutationtype"=>"Salutation"
@@ -245,17 +205,9 @@ $mod_list_strings = Array(
 	,"birthday"=>"Birthdate"
 	,"donotcall"=>"Do Not Call"
 	,"emailoptout"=>"Email Opt Out"
-	//,"primary_address_street_2"=>"Primary Address Street 2"
-	//,"primary_address_street_3"=>"Primary Address Street 3"
-	//,"alt_address_street_2"=>"Other Address Street 2"
-	//,"alt_address_street_3"=>"Other Address Street 3"
-	//,"full_name"=>"Full Name"
-	//,"account_name"=>"Account Name"
 	,"account_id"=>"Account Name"
 	,"title"=>"Title"
 	,"department"=>"Department"
-	//,"birthdate"=>"Birthdate"
-	//,"do_not_call"=>"Do Not Call"
 	,"homephone"=>"Phone (Home)"
 	,"mobile"=>"Phone (Mobile)"
 	,"phone"=>"Phone (Work)"
@@ -263,7 +215,7 @@ $mod_list_strings = Array(
 	,"fax"=>"Fax"
 	,"email"=>"Email"
 	,"otheremail"=>"Email (Other)"
-	,"yahooid"=>"Yahoo! ID"
+	,"secondaryemail"=>"Secondary Email"
 	,"assistant"=>"Assistant"
 	,"assistantphone"=>"Assistant Phone"
 	,"mailingstreet"=>"Mailing Address Street"
@@ -301,18 +253,12 @@ $mod_list_strings = Array(
 	"siccode"=>"SIC Code",
 	"annual_revenue"=>"Annual Revenue",
 	"bill_street"=>"Billing Address Street",
-	//"billing_address_street_2"=>"Billing Address Street 2",
-	//"billing_address_street_3"=>"Billing Address Street 3",
-	//"billing_address_street_4"=>"Billing Address Street 4",
 	"bill_pobox"=>"Billing Address PO Box",
 	"bill_city"=>"Billing Address City",
 	"bill_state"=>"Billing Address State",
 	"bill_code"=>"Billing Address Postalcode",
 	"bill_country"=>"Billing Address Country",
 	"ship_street"=>"Shipping Address Street",
-	//"shipping_address_street_2"=>"Shipping Address Street 2",
-	//"shipping_address_street_3"=>"Shipping Address Street 3",
-	//"shipping_address_street_4"=>"Shipping Address Street 4",
 	"ship_pobox"=>"Shipping Address PO Box",
 	"ship_city"=>"Shipping Address City",
 	"ship_state"=>"Shipping Address State",
@@ -356,7 +302,7 @@ $mod_list_strings = Array(
 		"rating"=>"Rating",
 		"noofemployees"=>"No Of Employees",
 		"assigned_user_id"=>"Assigned To",
-		"yahooid"=>"Yahoo Id",		
+		"secondaryemail"=>"Secondary Email",
 		"lane"=>"Street",
 		"pobox"=>"PO Box",
 		"code"=>"Postal Code",
