@@ -103,7 +103,7 @@ if (isset ($_REQUEST['record']) && $_REQUEST['record'] != '') {
 		//Handling for dateformat in vtiger_invoicedate vtiger_field
 		if ($focus->column_fields['invoicedate'] != '') {
 			$curr_due_date = $focus->column_fields['invoicedate'];
-			$focus->column_fields['invoicedate'] = getDBInsertDateValue($curr_due_date);
+			$focus->column_fields['invoicedate'] = DateTimeField::convertToDBFormat($curr_due_date);
 		}
 
 		$soid = $focus->column_fields['salesorder_id'];
@@ -137,7 +137,7 @@ if (isset ($_REQUEST['record']) && $_REQUEST['record'] != '') {
 		//Handling for dateformat in vtiger_invoicedate vtiger_field
 		if ($focus->column_fields['invoicedate'] != '') {
 			$curr_due_date = $focus->column_fields['invoicedate'];
-			$focus->column_fields['invoicedate'] = getDBInsertDateValue($curr_due_date);
+			$focus->column_fields['invoicedate'] = DateTimeField::convertToDBFormat($curr_due_date);
 		}
 
 		$soid = $focus->column_fields['salesorder_id'];
@@ -164,7 +164,9 @@ if (isset ($_REQUEST['record']) && $_REQUEST['record'] != '') {
 }
 if (isset ($_REQUEST['isDuplicate']) && $_REQUEST['isDuplicate'] == 'true') {
 	$smarty->assign("DUPLICATE_FROM", $focus->id);
-	$INVOICE_associated_prod = getAssociatedProducts("Invoice", $focus);
+	$INVOICE_associated_prod = getAssociatedProducts($currentModule, $focus);
+    $inventory_cur_info = getInventoryCurrencyInfo($currentModule, $focus->id);
+	$currencyid = $inventory_cur_info['currency_id'];
 	$focus->id = "";
 	$focus->mode = '';
 }
@@ -191,8 +193,8 @@ if (isset ($_REQUEST['product_id']) && $_REQUEST['product_id'] != '') {
 }
 if (!empty ($_REQUEST['parent_id']) && !empty ($_REQUEST['return_module'])) {
 	if ($_REQUEST['return_module'] == 'Services') {
-		$focus->column_fields['product_id'] = $_REQUEST['parent_id'];
-		$log->debug("Service Id from the request is " . $_REQUEST['parent_id']);
+		$focus->column_fields['product_id'] = vtlib_purify($_REQUEST['parent_id']);
+		$log->debug("Service Id from the request is " . vtlib_purify($_REQUEST['parent_id']));
 		$associated_prod = getAssociatedProducts("Services", $focus, $focus->column_fields['product_id']);
 	for ($i=1; $i<=count($associated_prod);$i++) {
 		$associated_prod_id = $associated_prod[$i]['hdnProductId'.$i];
@@ -370,7 +372,7 @@ if ($focus->mode != 'edit' && $mod_seq_field != null) {
 // END
 
 $smarty->assign("CURRENCIES_LIST", getAllCurrencies());
-if ($focus->mode == 'edit' || $_REQUEST['isDuplicate'] == 'true') {
+if ($focus->mode == 'edit') {
 	$inventory_cur_info = getInventoryCurrencyInfo('Invoice', $focus->id);
 	$smarty->assign("INV_CURRENCY_ID", $inventory_cur_info['currency_id']);
 } else {
@@ -380,8 +382,17 @@ if ($focus->mode == 'edit' || $_REQUEST['isDuplicate'] == 'true') {
 $check_button = Button_Check($module);
 $smarty->assign("CHECK", $check_button);
 $smarty->assign("DUPLICATE",vtlib_purify($_REQUEST['isDuplicate']));
+
+$picklistDependencyDatasource = Vtiger_DependencyPicklist::getPicklistDependencyDatasource($currentModule);
+$smarty->assign("PICKIST_DEPENDENCY_DATASOURCE", Zend_Json::encode($picklistDependencyDatasource));
+
+// Gather the help information associated with fields
+$smarty->assign('FIELDHELPINFO', vtlib_getFieldHelpInfo($currentModule));
+// END
+
 if ($focus->mode == 'edit')
 	$smarty->display("Inventory/InventoryEditView.tpl");
 else
 	$smarty->display('Inventory/InventoryCreateView.tpl');
+
 ?>
\ No newline at end of file
