@@ -90,9 +90,11 @@ class jpgraph {
 			$first = true;
 			$current = 0;
 
+			$date = new DateTimeField($date_start);
+			$endDate = new DateTimeField($date_end);
 			//build the where clause for the query that matches $date_start and $date_end
 			$where .= " closingdate >= '$date_start' AND closingdate <= '$date_end'";
-			$subtitle = $current_module_strings['LBL_DATE_RANGE']." ".getDisplayDate($date_start)." ".$current_module_strings['LBL_DATE_RANGE_TO']." ".getDisplayDate($date_end)."\n";
+			$subtitle = $current_module_strings['LBL_DATE_RANGE']." ".$date->getDisplayDate()." ".$current_module_strings['LBL_DATE_RANGE_TO']." ".$endDate->getDisplayDate()."\n";
 
 			//Now do the db queries
 			//query for opportunity data that matches $datay and $user
@@ -152,7 +154,8 @@ class jpgraph {
 				foreach($stages as $stage) {
 					$log->debug("stage is $stage");
 					foreach ($user_id as $the_id) {
-						$the_user = get_assigned_user_name($the_id);
+						$the_user = getEntityName('Users', $the_id);
+						$the_user = $the_user[$the_id];
 						if (!isset($datax[$stage][$the_id])) {
 							$datax[$stage][$the_id] = array();
 						}
@@ -481,7 +484,8 @@ class jpgraph {
 			  	}
 			  	foreach($stages as $stage) {
 					foreach ($user_id as $the_id) {
-						$the_user = get_assigned_user_name($the_id);
+						$the_user = getEntityName('Users', $the_id);
+						$the_user = $the_user[$the_id];
 						$log->debug("stage_key is $stage");
 						if (!isset($datax[$stage][$the_id])) {
 							$datax[$stage][$the_id] = array();
@@ -747,9 +751,11 @@ class jpgraph {
 				$where .= ")";
 			}
 
+			$date = new DateTimeField($date_start);
+			$endDate = new DateTimeField($date_end);
 			//build the where clause for the query that matches $date_start and $date_end
 			$where .= " AND closingdate >= '$date_start' AND closingdate <= '$date_end'";
-			$subtitle = $current_module_strings['LBL_DATE_RANGE']." ".getDisplayDate($date_start)." ".$current_module_strings['LBL_DATE_RANGE_TO']." ".getDisplayDate($date_end)."\n";
+			$subtitle = $current_module_strings['LBL_DATE_RANGE']." ".$date->getDisplayDate()." ".$current_module_strings['LBL_DATE_RANGE_TO']." ".$endDate->getDisplayDate()."\n";
 
 			//Now do the db queries
 			//query for opportunity data that matches $datax and $user
@@ -785,7 +791,8 @@ class jpgraph {
 			$aAlts = array();
 			foreach ($datax as $stage_key=>$stage_translation) {
 			  foreach ($user_id as $the_id) {
-			  	$the_user = get_assigned_user_name($the_id);
+			  	$the_user = getEntityName('Users', $the_id);
+				$the_user = $the_user[$the_id];
 				if (!isset($datay[$the_id])) {
 					$datay[$the_id] = array();
 				}
