@@ -28,10 +28,6 @@ if($ajaxaction == "DETAILVIEW")
 		$modObj->retrieve_entity_info($crmid,"Potentials");
 		$modObj->column_fields[$fieldname] = $fieldvalue;
 		$_REQUEST[$fieldname] = $fieldvalue;
-		if($fieldname == 'amount')//amount converted to dollar value while saving
-		{
-			$modObj->column_fields[$fieldname] = getConvertedPrice($fieldvalue);
-		}	
 		$modObj->id = $crmid;
 		$modObj->mode = "edit";
 		$modObj->save("Potentials");
