@@ -11,6 +11,8 @@ require_once('modules/Reports/Reports.php');
 require_once('include/logging.php');
 require_once('include/database/PearDatabase.php');
 require_once("include/Zend/Json.php");
+require_once 'modules/Reports/ReportUtils.php';
+
 global $adb;
 global $log,$current_user;
 $reportid = vtlib_purify($_REQUEST["record"]);
@@ -52,8 +54,8 @@ $folderid = vtlib_purify($_REQUEST["folder"]);
 //<<<<<<<standarfilters>>>>>>>>>
 $stdDateFilterField = vtlib_purify($_REQUEST["stdDateFilterField"]);
 $stdDateFilter = vtlib_purify($_REQUEST["stdDateFilter"]);
-$startdate = getDBInsertDateValue($_REQUEST["startdate"]);
-$enddate = getDBInsertDateValue($_REQUEST["enddate"]);
+$startdate = DateTimeField::convertToDBFormat($_REQUEST["startdate"]);
+$enddate = DateTimeField::convertToDBFormat($_REQUEST["enddate"]);
 //<<<<<<<standardfilters>>>>>>>>>
 
 //<<<<<<<shared entities>>>>>>>>>
@@ -83,6 +85,13 @@ $advft_criteria_groups = $_REQUEST['advft_criteria_groups'];
 $advft_criteria_groups = $json->decode($advft_criteria_groups);
 //<<<<<<<advancedfilter>>>>>>>>
 
+//<<<<<<<scheduled report>>>>>>>>
+$isReportScheduled		= vtlib_purify($_REQUEST['isReportScheduled']);
+$selectedRecipients	= vtlib_purify($_REQUEST['selectedRecipientsString']);
+$scheduledFormat	= vtlib_purify($_REQUEST['scheduledReportFormat']);
+$scheduledInterval	= vtlib_purify($_REQUEST['scheduledIntervalString']);
+//<<<<<<<scheduled report>>>>>>>>
+
 if($reportid == "")
 {
 	$genQueryId = $adb->getUniqueID("vtiger_selectquery");
@@ -180,15 +189,41 @@ if($reportid == "")
 						$adv_filter_groupid = $column_condition["groupid"];
 					
 						$column_info = explode(":",$adv_filter_column);
+						$moduleFieldLabel = $column_info[2];
+						$fieldName = $column_info[3];
+
+						list($module, $fieldLabel) = explode('_', $moduleFieldLabel, 2);
+						$fieldInfo = getFieldByReportLabel($module, $fieldLabel);
+						$fieldType = null;
+						if(!empty($fieldInfo)) {
+							$field = WebserviceField::fromArray($adb, $fieldInfo);
+							$fieldType = $field->getFieldDataType();
+						}
+						
+						if($fieldType == 'currency') {
+							if($field->getUIType() == '71') {
+								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value, null, true);
+							} else {
+								$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value);
+							}
+						}
+						
 						$temp_val = explode(",",$adv_filter_value);
 						if(($column_info[4] == 'D' || ($column_info[4] == 'T' && $column_info[1] != 'time_start' && $column_info[1] != 'time_end') || ($column_info[4] == 'DT')) && ($column_info[4] != '' && $adv_filter_value != '' ))
 						{
 							$val = Array();
 							for($x=0;$x<count($temp_val);$x++) {
-								list($temp_date,$temp_time) = explode(" ",$temp_val[$x]);
-								$temp_date = getDBInsertDateValue(trim($temp_date));
-								$val[$x] = $temp_date;
-								if($temp_time != '') $val[$x] = $val[$x].' '.$temp_time;
+								if(trim($temp_val[$x]) != '') {
+									$date = new DateTimeField(trim($temp_val[$x]));
+									if($column_info[4] == 'D') {
+										$val[$x] = DateTimeField::convertToUserFormat(
+												trim($temp_val[$x]));
+									} elseif($column_info[4] == 'DT') {
+										$val[$x] = $date->getDBInsertDateTimeValue();
+									} else {
+										$val[$x] = $date->getDBInsertTimeValue();
+									}
+								}
 							}
 							$adv_filter_value = implode(",",$val);
 						}
@@ -208,6 +243,7 @@ if($reportid == "")
 					foreach($advft_criteria_groups as $group_index => $group_condition_info) {				
 						
 						if(empty($group_condition_info)) continue;
+						if(empty($group_condition_info["conditionexpression"])) continue; // Case when the group doesn't have any column criteria
 						
 						$irelcriteriagroupsql = "insert into vtiger_relcriteria_grouping(GROUPID,QUERYID,GROUP_CONDITION,CONDITION_EXPRESSION) values (?,?,?,?)";
 						$irelcriteriagroupresult = $adb->pquery($irelcriteriagroupsql, array($group_index, $genQueryId, $group_condition_info["groupcondition"], $group_condition_info["conditionexpression"]));
@@ -215,6 +251,13 @@ if($reportid == "")
 					$log->info("Reports :: Save->Successfully saved vtiger_relcriteria");
 					//<<<<step5 advancedfilter>>>>>>>
 
+					//<<<<step7 scheduledReport>>>>>>>
+					if($isReportScheduled == 'on' || $isReportScheduled == '1'){
+						$scheduleReportSql = 'INSERT INTO vtiger_scheduled_reports (reportid,recipients,schedule,format,next_trigger_time) VALUES (?,?,?,?,?)';
+						$adb->pquery($scheduleReportSql, array($genQueryId,$selectedRecipients,$scheduledInterval,$scheduledFormat,date("Y-m-d H:i:s")));
+					}
+					//<<<<step7 scheduledReport>>>>>>>
+
 				}else
 				{
 					$errormessage = "<font color='red'><B>Error Message<ul>
@@ -342,15 +385,42 @@ if($reportid == "")
 				$adv_filter_groupid = $column_condition["groupid"];
 			
 				$column_info = explode(":",$adv_filter_column);
+				$moduleFieldLabel = $column_info[2];
+				$fieldName = $column_info[3];
+
+				list($module, $fieldLabel) = explode('_', $moduleFieldLabel, 2);
+				$fieldInfo = getFieldByReportLabel($module, $fieldLabel);
+				$fieldType = null;
+				if(!empty($fieldInfo)) {
+					$field = WebserviceField::fromArray($adb, $fieldInfo);
+					$fieldType = $field->getFieldDataType();
+				}
+
+				if($fieldType == 'currency') {
+					// Some of the currency fields like Unit Price, Total, Sub-total etc of Inventory modules, do not need currency conversion
+					if($field->getUIType() == '72') {
+						$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value, null, true);
+					} else {
+						$adv_filter_value = CurrencyField::convertToDBFormat($adv_filter_value);
+					}
+				}
+				
 				$temp_val = explode(",",$adv_filter_value);
 				if(($column_info[4] == 'D' || ($column_info[4] == 'T' && $column_info[1] != 'time_start' && $column_info[1] != 'time_end') || ($column_info[4] == 'DT')) && ($column_info[4] != '' && $adv_filter_value != '' ))
 				{
 					$val = Array();
 					for($x=0;$x<count($temp_val);$x++) {
-						list($temp_date,$temp_time) = explode(" ",$temp_val[$x]);
-						$temp_date = getDBInsertDateValue(trim($temp_date));
-						$val[$x] = $temp_date;
-						if($temp_time != '') $val[$x] = $val[$x].' '.$temp_time;
+						if(trim($temp_val[$x]) != '') {
+							$date = new DateTimeField(trim($temp_val[$x]));
+							if($column_info[4] == 'D') {
+								$val[$x] = DateTimeField::convertToUserFormat(
+										trim($temp_val[$x]));
+							} elseif($column_info[4] == 'DT') {
+								$val[$x] = $date->getDBInsertDateTimeValue();
+							} else {
+								$val[$x] = $date->getDBInsertTimeValue();
+							}
+						}
 					}
 					$adv_filter_value = implode(",",$val);
 				}
@@ -370,6 +440,7 @@ if($reportid == "")
 			foreach($advft_criteria_groups as $group_index => $group_condition_info) {				
 						
 				if(empty($group_condition_info)) continue;
+				if(empty($group_condition_info["conditionexpression"])) continue; // Case when the group doesn't have any column criteria
 									
 				$irelcriteriagroupsql = "insert into vtiger_relcriteria_grouping(GROUPID,QUERYID,GROUP_CONDITION,CONDITION_EXPRESSION) values (?,?,?,?)";
 				$irelcriteriagroupresult = $adb->pquery($irelcriteriagroupsql, array($group_index, $reportid, $group_condition_info["groupcondition"], $group_condition_info["conditionexpression"]));
@@ -377,6 +448,23 @@ if($reportid == "")
 			$log->info("Reports :: Save->Successfully saved vtiger_relcriteria");
 			//<<<<step5 advancedfilter>>>>>>>
 
+			//<<<<step7 scheduledReport>>>>>>>
+			if($isReportScheduled == 'off' || $isReportScheduled == '0' || $isReportScheduled == '') {
+				$deleteScheduledReportSql = "DELETE FROM vtiger_scheduled_reports WHERE reportid=?";
+				$adb->pquery($deleteScheduledReportSql, array($reportid));
+			} else{
+				$checkScheduledResult = $adb->pquery('SELECT 1 FROM vtiger_scheduled_reports WHERE reportid=?', array($reportid));
+
+				if($adb->num_rows($checkScheduledResult) > 0) {
+					$scheduledReportSql = 'UPDATE vtiger_scheduled_reports SET recipients=?,schedule=?,format=? WHERE reportid=?';
+					$adb->pquery($scheduledReportSql, array($selectedRecipients,$scheduledInterval,$scheduledFormat,$reportid));
+				} else {
+					$scheduleReportSql = 'INSERT INTO vtiger_scheduled_reports (reportid,recipients,schedule,format,next_trigger_time) VALUES (?,?,?,?,?)';
+					$adb->pquery($scheduleReportSql, array($reportid,$selectedRecipients,$scheduledInterval,$scheduledFormat,date("Y-m-d H:i:s")));
+				}
+			}
+			//<<<<step7 scheduledReport>>>>>>>
+			
 		}else
 		{
 			$errormessage = "<font color='red'><B>Error Message<ul>
