@@ -12,7 +12,7 @@ include_once 'modules/SalesOrder/SalesOrderPDFController.php';
 
 $controller = new Vtiger_SalesOrderPDFController($currentModule);
 $controller->loadRecord(vtlib_purify($_REQUEST['record']));
-
-$controller->Output('SalesOrder.pdf', 'D');//added file name to make it work in IE, also forces the download giving the user the option to save
+$salesorder_no = getModuleSequenceNumber($currentModule,vtlib_purify($_REQUEST['record']));
+$controller->Output('SalesOrder_'.$salesorder_no.'.pdf', 'D');//added file name to make it work in IE, also forces the download giving the user the option to save
 exit();
 ?>
