@@ -1,13 +1,12 @@
 <?php
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
-  ********************************************************************************/
+ ********************************************************************************/
 
 global $adb;
 
@@ -17,10 +16,8 @@ elseif($_REQUEST['idlist'] != '')
 	$idlist = $_REQUEST['idlist'];
 
 $selected_array = explode(";",$idlist);
-foreach($selected_array as $account_id)
-{
-	if($account_id != '')
-	{
+foreach($selected_array as $account_id) {
+	if($account_id != '') 	{
 		$query = "update vtiger_mail_accounts set status=0 where account_id=?";
 		$adb->pquery($query, array($account_id));
 	}
@@ -28,4 +25,4 @@ foreach($selected_array as $account_id)
 
 header("Location:index.php?module=Settings&action=ListMailAccount");
 
-?>
+?>
\ No newline at end of file
