@@ -851,8 +851,11 @@ $mod_strings = Array(
 'LBL_PRIVATE'=>'Private',
  
 'Public: Read Only'=>'Public: Read Only',
+
 'Public: Read, Create/Edit'=>'Public: Read, Create/Edit',
+
 'Public: Read, Create/Edit, Delete'=>'Public: Read, Create/Edit, Delete',
+
 'Private'=>'Private',
 'Hide Details'=>'Hide Details',
 'Hide Details and Add Events'=>'Hide Details and Add Events',
@@ -1202,5 +1205,46 @@ $mod_strings = Array(
 'LBL_ADD_CUSTOMFIELD' => 'Add Custom Field',
 
 'ERR_INVALID_PROFILE_ID' => 'Invalid Profile Id. Please specify valid Profile Id',
+
+// Customization
+'LBL_PUBLISHER' => 'Publisher',
+'LBL_PUBLISHED_ON' => 'Published On',
+'LBL_LICENSE'   => 'License',
+'LBL_EXTENSION_FILE_DOWNLOAD_FAILED' => 'Failed to download the extension package!',
+'LBL_DEFAULT'=>'By default, SMTP account settings for the outgoing server are configured to od1.vtiger.com mail server. To avoid outgoing emails getting filtered out by spam filters on your recipient ISP mail server, we recommend you implement one of the following.',
+'LBL_OPTIONS1'=>'Send emails from your mail server<br>
+				- Enter the SMTP account details (Server Name, User Name, Password) for the same account as entered in the FROM email address.',
+'LBL_OPTIONS2'=>"Add od1.vtiger.com server as a authorized sender for your domain.<br>
+				- If you prefer to retain the vtiger server as the outgoing server, we recommend that you configure your domain's SPF record to include the vtiger server as a valid sender for your domain.
+				  For additonal instruction on setting up SPF record, please email od-support@vtiger.com .",
+'LBL_ALREADY_EXISTS' => 'Already Exists',
+'LBL_EXTENSION_INCOMPATIBLE' => 'Extension Incompatible',
+'LBL_INSTALL' => 'Install',
+'LBL_DEFAULT_SETTINGS_BUTTON_TITLE' => 'Reset To Default',
+'LBL_CONFIRM_DEFAULT_SETTINGS' => 'Are you sure that you want to change the server details to the default server values',
+'EXISTING_DEFAULT_VALUES' => 'The server details are already set to the default values',
+'LBL_NOTE' => 'Note:',
+'LBL_HIDE' => 'Hide Details',
+'LBL_SHOW' => 'Show Details',
+// END
+'LBL_USER_ADDITION_INFO'=>"To add a new user, please click on  
+			   <span style='font-style:italic;color:blue;'>OD-Settings Menu -> On Demand Admin -> Add User </span>",
+
+'LBL_READ_ONLY_ACCESS_MSG' => 'Read-Only Access',
+'LBL_READ_WRITE_ACCESS_MSG' => 'Read-Write Access',
+
+'LBL_DEFAULT_VALUE' => 'Default Value',
+
+'LBL_DESCRIPTION_Public: Read Only'=>'Users can Read Only other users ',
+'LBL_DESCRIPTION_Public: Read, Create/Edit'=>'Users can Read, Create/Edit other users ',
+'LBL_DESCRIPTION_Public: Read, Create/Edit, Delete'=>'Users can Read, Create/Edit, Delete other users ',
+
+// For Dependency picklist
+'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Picklist Dependency Setup',
+'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Setup Dependency between Picklist values in each module',
+
+'Settings' => 'Settings',
+'LBL_ERR_TAX_LABEL_ALREADY_EXISTS' => 'This tax is already available.',
+'LBL_ERR_SOME_TAX_LABELS_ALREADY_EXISTS' => 'Some tax labels are already available, hence not saved.',
 );
-?>
+?>
\ No newline at end of file
