@@ -1,20 +1,17 @@
 <?php
-
-/*********************************************************************************
-** The contents of this file are subject to the vtiger CRM Public License Version 1.0
+/*+********************************************************************************
+ * The contents of this file are subject to the vtiger CRM Public License Version 1.0
  * ("License"); You may not use this file except in compliance with the License
  * The Original Code is:  vtiger CRM Open Source
  * The Initial Developer of the Original Code is vtiger.
  * Portions created by vtiger are Copyright (C) vtiger.
  * All Rights Reserved.
-*
  ********************************************************************************/
 
-
-require_once('include/database/PearDatabase.php');
 require_once('include/utils/utils.php');
 
-$profilename=$_REQUEST['profile_name'];
+global $mod_strings;
+$profilename=vtlib_purify($_REQUEST['profile_name']);
 
 if(isset($_REQUEST['dup_check']) && $_REQUEST['dup_check']!='')
 {
@@ -23,11 +20,11 @@ if(isset($_REQUEST['dup_check']) && $_REQUEST['dup_check']!='')
 
         if($adb->num_rows($result) > 0)
         {
-                echo 'A Profile in the specified name "'.$profilename.'" already exists';
+                echo $mod_strings['LBL_PROFILENAME_EXIST'];
                 die;
         }else
         {
-                echo 'SUCESS';
+                echo 'SUCCESS';
                 die;
         }
 
@@ -40,17 +37,18 @@ $image_path=$theme_path."images/";
 $smarty = new vtigerCRM_Smarty;
 
 if(isset($_REQUEST['parent_profile']) && $_REQUEST['parent_profile'] != '')
-	$smarty->assign("PARENT_PROFILE",$_REQUEST['parent_profile']);
+	$smarty->assign("PARENT_PROFILE",vtlib_purify($_REQUEST['parent_profile']));
 if(isset($_REQUEST['radio_button']) && $_REQUEST['radio_button'] != '')
-	$smarty->assign("RADIO_BUTTON",$_REQUEST['radio_button']);
+	$smarty->assign("RADIO_BUTTON",vtlib_purify($_REQUEST['radio_button']));
 if(isset($_REQUEST['profile_name']) && $_REQUEST['profile_name'] != '')
-	$smarty->assign("PROFILE_NAME",$_REQUEST['profile_name']);
+	$smarty->assign("PROFILE_NAME",vtlib_purify($_REQUEST['profile_name']));
 if(isset($_REQUEST['profile_description']) && $_REQUEST['profile_description'] != '')
-	$smarty->assign("PROFILE_DESCRIPTION",$_REQUEST['profile_description']);
+	$smarty->assign("PROFILE_DESCRIPTION",vtlib_purify($_REQUEST['profile_description']));
 if(isset($_REQUEST['mode']) && $_REQUEST['mode'] != '')
-	$smarty->assign("MODE",$_REQUEST['mode']);
+	$smarty->assign("MODE",vtlib_purify($_REQUEST['mode']));
 
 $smarty->assign("MOD", return_module_language($current_language,'Settings'));
+$smarty->assign("THEME", $theme);
 $smarty->assign("IMAGE_PATH",$image_path);
 $smarty->assign("APP", $app_strings);
 $smarty->assign("CMOD", $mod_strings);
@@ -66,5 +64,5 @@ do
 	$profilelist[] = array($name,$profileid); 
 }while($temprow = $adb->fetch_array($result));
 $smarty->assign("PROFILE_LISTS", $profilelist);
-                    
 $smarty->display("CreateProfile.tpl");
+?>
\ No newline at end of file
