@@ -51,5 +51,25 @@ $mod_strings = array(
 'Created Time'=>'Created Time',
 'Modified Time'=>'Modified Time',
 
+// Added after 5.0.4 GA
+
+//added for find duplicate
+'LBL_DUPLICATE_DATA_IN'=>'Duplicate ',
+'LBL_DELETE'=>'Delete',
+'LBL_MERGE_SELECT'=>'Merge Select',
+'LBL_MERGE'=>'Merge',
+'LBL_MERGE_DATA_IN'=>'Merge Records In',
+'LBL_ACTION'=>'Action',
+'LBL_FIELDLISTS'=> 'List Of Fields',
+'LBL_RECORD'=>'Record #',
+
+// Module Sequence Numbering
+'Vendor No' => 'Vendor No',
+// END
+
+/*
+ * 5.2.0 changes 
+ */
+'LBL_MODULE_NAME'=>'Vendors',
 );
 ?>
