@@ -8,10 +8,9 @@
  * All Rights Reserved.
  ************************************************************************************/
 global $currentModule;
+$modObj = CRMEntity::getInstance($currentModule);
 
-require_once("modules/$currentModule/$currentModule.php");
-
-$ajaxaction = $_REQUEST['ajxaction'];
+$ajaxaction = $_REQUEST["ajxaction"];
 if($ajaxaction == 'DETAILVIEW')
 {
 	$crmid = $_REQUEST['recordid'];
@@ -20,7 +19,6 @@ if($ajaxaction == 'DETAILVIEW')
 	$fieldvalue = utf8RawUrlDecode($_REQUEST['fieldValue']); 
 	if($crmid != '')
 	{
-		$modObj = new $currentModule();
 		$modObj->retrieve_entity_info($crmid, $currentModule);
 		$modObj->column_fields[$fieldname] = $fieldvalue;
 		$modObj->id = $crmid;
@@ -37,5 +35,7 @@ if($ajaxaction == 'DETAILVIEW')
 	{
 		echo ':#:FAILURE';
 	}
+} elseif($ajaxaction == "LOADRELATEDLIST" || $ajaxaction == "DISABLEMODULE"){
+	require_once 'include/ListView/RelatedListViewContents.php';
 }
-?>
+?>
\ No newline at end of file
