@@ -11,77 +11,90 @@ require_once('data/CRMEntity.php');
 require_once('data/Tracker.php');
 
 class ModuleClass extends CRMEntity {
-	var $db, $log; // Used in class functions like CRMEntity
+	var $db, $log; // Used in class functions of CRMEntity
 
 	var $table_name = 'vtiger_payslip';
 	var $table_index= 'payslipid';
 	var $column_fields = Array();
 
-	// Indicator if this is a custom module or standard module
+	/** Indicator if this is a custom module or standard module */
 	var $IsCustomModule = true;
 
-	// Mandatory for function getGroupName
-	// Array(groupTableName, groupColumnId)
-	// groupTableName should have (groupname column)
-	var $groupTable = Array('vtiger_payslipgrouprel', 'payslipid');
-
-	// Mandatory table for supporting custom fields
+	/**
+	 * Mandatory table for supporting custom fields.
+	 */
 	var $customFieldTable = Array('vtiger_payslipcf', 'payslipid');
 
-	// Mandatory for Saving, Include tables related to this module.
+	/**
+	 * Mandatory for Saving, Include tables related to this module.
+	 */
 	var $tab_name = Array('vtiger_crmentity', 'vtiger_payslip', 'vtiger_payslipcf');
-	// Mandatory for Saving, Include the table name and index column mapping here.
+
+	/**
+	 * Mandatory for Saving, Include tablename and tablekey columnname here.
+	 */
 	var $tab_name_index = Array(
 		'vtiger_crmentity' => 'crmid',
 		'vtiger_payslip'   => 'payslipid',
 	    'vtiger_payslipcf' => 'payslipid');
 
-	// Mandatory for Listing
+	/**
+	 * Mandatory for Listing (Related listview)
+	 */
 	var $list_fields = Array (
-		// Field Label=> Array(tablename, columnname)
+		/* Format: Field Label => Array(tablename, columnname) */
+		// tablename should not have prefix 'vtiger_'
 		'Payslip Name'=> Array('payslip', 'payslipname'),
 		'Assigned To' => Array('crmentity','smownerid')
 	);
 	var $list_fields_name = Array(
-		// Field Label=>fieldname
+		/* Format: Field Label => fieldname */
 		'Payslip Name'=> 'payslipname',
 		'Assigned To' => 'assigned_user_id'
 	);
 
-	// Make the field link detail view from list view (Fieldname)
+	// Make the field link to detail view from list view (Fieldname)
 	var $list_link_field = 'payslipname';
-	
-	// For Popup listview
+
+	// For Popup listview and UI type support
 	var $search_fields = Array(
+		/* Format: Field Label => Array(tablename, columnname) */
+		// tablename should not have prefix 'vtiger_'
 		'Payslip Name'=> Array('payslip', 'payslipname')
 	);
 	var $search_fields_name = Array(
+		/* Format: Field Label => fieldname */
 		'Payslip Name'=> 'payslipname'
 	);
 
+	// For Popup window record selection
 	var $popup_fields = Array('payslipname');
 
-	var $sortby_fields = Array('payslipname', 'payslipmonth', 'smownerid', 'modifiedtime');
+	// Placeholder for sort fields - All the fields will be initialized for Sorting through initSortFields
+	var $sortby_fields = Array();
 
-	// For alphabetical search
+	// For Alphabetical search
 	var $def_basicsearch_col = 'payslipname';
 
-	// Column value to use on detail view record text display.
+	// Column value to use on detail view record text display
 	var $def_detailview_recname = 'payslipname';
 
-	// Required information for enabling Import feature
+	// Required Information for enabling Import feature
 	var $required_fields = Array('payslipname'=>1);
 
 	// Callback function list during Importing
-	var $special_functions =  array("set_import_assigned_user");
+	var $special_functions = Array('set_import_assigned_user');
 
 	var $default_order_by = 'payslipname';
 	var $default_sort_order='ASC';
-
+	// Used when enabling/disabling the mandatory fields for the module.
+	// Refers to vtiger_field.fieldname values.
+	var $mandatory_fields = Array('createdtime', 'modifiedtime', 'payslipname');
+	
 	function __construct() {
 		global $log, $currentModule;
 		$this->column_fields = getColumnFields($currentModule);
-		$this->db = new PearDatabase();
+		$this->db = PearDatabase::getInstance();
 		$this->log = $log;
 	}
 
@@ -99,7 +112,12 @@ class ModuleClass extends CRMEntity {
 	function getOrderBy() {
 		global $currentModule;
 		
-		$orderby = $this->default_order_by;
+		$use_default_order_by = '';		
+		if(PerformancePrefs::getBoolean('LISTVIEW_DEFAULT_SORTING', true)) {
+			$use_default_order_by = $this->default_order_by;
+		}
+		
+		$orderby = $use_default_order_by;
 		if($_REQUEST['order_by']) $orderby = $this->db->sql_escape_string($_REQUEST['order_by']);
 		else if($_SESSION[$currentModule.'_Order_By'])
 			$orderby = $_SESSION[$currentModule.'_Order_By'];
@@ -113,15 +131,18 @@ class ModuleClass extends CRMEntity {
 	 * Return query to use based on given modulename, fieldname
 	 * Useful to handle specific case handling for Popup
 	 */
-	function getQueryByModuleField($module, $fieldname, $srcrecord) {
+	function getQueryByModuleField($module, $fieldname, $srcrecord, $query='') {
 		// $srcrecord could be empty
 	}
 
 	/**
 	 * Get list view query (send more WHERE clause condition if required)
 	 */
-	function getListQuery($module, $usewhere=false) {
+	function getListQuery($module, $usewhere='') {
 		$query = "SELECT vtiger_crmentity.*, $this->table_name.*";
+		
+		// Keep track of tables joined to avoid duplicates
+		$joinedTables = array();
 
 		// Select Custom Field Table Columns if present
 		if(!empty($this->customFieldTable)) $query .= ", " . $this->customFieldTable[0] . ".* ";
@@ -130,23 +151,43 @@ class ModuleClass extends CRMEntity {
 
 		$query .= "	INNER JOIN vtiger_crmentity ON vtiger_crmentity.crmid = $this->table_name.$this->table_index";
 
+		$joinedTables[] = $this->table_name;
+		$joinedTables[] = 'vtiger_crmentity';
+		
 		// Consider custom table join as well.
 		if(!empty($this->customFieldTable)) {
 			$query .= " INNER JOIN ".$this->customFieldTable[0]." ON ".$this->customFieldTable[0].'.'.$this->customFieldTable[1] .
-				      " = $this->table_name.$this->table_index"; 
+				      " = $this->table_name.$this->table_index";
+			$joinedTables[] = $this->customFieldTable[0]; 
 		}
 		$query .= " LEFT JOIN vtiger_users ON vtiger_users.id = vtiger_crmentity.smownerid";
+		$query .= " LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid";
 
-		if(!empty($this->groupTable)) {
-			$query .= "
-				LEFT JOIN " . $this->groupTable[0] . " ON " . $this->groupTable[0].'.'.$this->groupTable[1] . " = $this->table_name.$this->table_index
-				LEFT JOIN vtiger_groups ON vtiger_groups.groupname = " . $this->groupTable[0] . '.groupname';
-		}
-		$query .= "	WHERE vtiger_crmentity.deleted = 0";
-		$query .= $this->getListViewSecurityParameter($module);
-		if($usewhere) {
-			$query .= " $usewhere ";
+		$joinedTables[] = 'vtiger_users';
+		$joinedTables[] = 'vtiger_groups';
+		
+		$linkedModulesQuery = $this->db->pquery("SELECT distinct fieldname, columnname, relmodule FROM vtiger_field" .
+				" INNER JOIN vtiger_fieldmodulerel ON vtiger_fieldmodulerel.fieldid = vtiger_field.fieldid" .
+				" WHERE uitype='10' AND vtiger_fieldmodulerel.module=?", array($module));
+		$linkedFieldsCount = $this->db->num_rows($linkedModulesQuery);
+		
+		for($i=0; $i<$linkedFieldsCount; $i++) {
+			$related_module = $this->db->query_result($linkedModulesQuery, $i, 'relmodule');
+			$fieldname = $this->db->query_result($linkedModulesQuery, $i, 'fieldname');
+			$columnname = $this->db->query_result($linkedModulesQuery, $i, 'columnname');
+			
+			$other =  CRMEntity::getInstance($related_module);
+			vtlib_setup_modulevars($related_module, $other);
+			
+			if(!in_array($other->table_name, $joinedTables)) {
+				$query .= " LEFT JOIN $other->table_name ON $other->table_name.$other->table_index = $this->table_name.$columnname";
+				$joinedTables[] = $other->table_name;
+			}
 		}
+
+		global $current_user;
+		$query .= $this->getNonAdminAccessControlQuery($module,$current_user);
+		$query .= "	WHERE vtiger_crmentity.deleted = 0 ".$usewhere;
 		return $query;
 	}
 
@@ -177,11 +218,6 @@ class ModuleClass extends CRMEntity {
 						WHERE userid=".$current_user->id." AND tabid=".$tabid."
 					) 
 					OR 
-					(
-						vtiger_crmentity.smownerid in (0)";
-
-				if(!empty($this->groupTable)) {
-					$sec_query .= " AND 
 						(";
 		
 					// Build the query based on the group association of current user.
@@ -194,9 +230,6 @@ class ModuleClass extends CRMEntity {
 							FROM vtiger_tmp_read_group_sharing_per
 							WHERE userid=".$current_user->id." and tabid=".$tabid."
 						)";
-					$sec_query .= ") ";
-				}
-
 				$sec_query .= ")
 				)";
 		}
@@ -218,34 +251,39 @@ class ModuleClass extends CRMEntity {
 		
 		$fields_list = getFieldsListFromQuery($sql);
 
-		$query = "SELECT $fields_list, ". $this->groupTable[0].'.'.$this->groupTable[1] ." as 'Assigned To Group', 
-				CASE WHEN (vtiger_users.user_name NOT LIKE '') THEN vtiger_users.user_name ELSE vtiger_groups.groupname END 
-				AS user_name FROM vtiger_crmentity INNER JOIN $this->table_name ON vtiger_crmentity.crmid=$this->table_name.$this->table_index";
+		$query = "SELECT $fields_list, vtiger_users.user_name AS user_name 
+					FROM vtiger_crmentity INNER JOIN $this->table_name ON vtiger_crmentity.crmid=$this->table_name.$this->table_index";
 
 		if(!empty($this->customFieldTable)) {
 			$query .= " INNER JOIN ".$this->customFieldTable[0]." ON ".$this->customFieldTable[0].'.'.$this->customFieldTable[1] .
 				      " = $this->table_name.$this->table_index"; 
 		}
 
-		$query .= " 
-			LEFT JOIN " . $this->groupTable[0] . " ON " . $this->groupTable[0].'.'.$this->groupTable[1] . " = $this->table_name.$this->table_index
-			LEFT JOIN vtiger_groups ON vtiger_groups.groupname = " . $this->groupTable[0] . '.groupname';
+		$query .= " LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid";
 		$query .= " LEFT JOIN vtiger_users ON vtiger_crmentity.smownerid = vtiger_users.id and vtiger_users.status='Active'";
+		
+		$linkedModulesQuery = $this->db->pquery("SELECT distinct fieldname, columnname, relmodule FROM vtiger_field" .
+				" INNER JOIN vtiger_fieldmodulerel ON vtiger_fieldmodulerel.fieldid = vtiger_field.fieldid" .
+				" WHERE uitype='10' AND vtiger_fieldmodulerel.module=?", array($thismodule));
+		$linkedFieldsCount = $this->db->num_rows($linkedModulesQuery);
 
+		for($i=0; $i<$linkedFieldsCount; $i++) {
+			$related_module = $this->db->query_result($linkedModulesQuery, $i, 'relmodule');
+			$fieldname = $this->db->query_result($linkedModulesQuery, $i, 'fieldname');
+			$columnname = $this->db->query_result($linkedModulesQuery, $i, 'columnname');
+			
+			$other = CRMEntity::getInstance($related_module);
+			vtlib_setup_modulevars($related_module, $other);
+			
+			$query .= " LEFT JOIN $other->table_name ON $other->table_name.$other->table_index = $this->table_name.$columnname";
+		}
+
+		$query .= $this->getNonAdminAccessControlQuery($thismodule,$current_user);
 		$where_auto = " vtiger_crmentity.deleted=0";
 
 		if($where != '') $query .= " WHERE ($where) AND $where_auto";
 		else $query .= " WHERE $where_auto";
 
-		require('user_privileges/user_privileges_'.$current_user->id.'.php');
-		require('user_privileges/sharing_privileges_'.$current_user->id.'.php');
-
-		// Security Check for Field Access
-		if($is_admin==false && $profileGlobalPermission[1] == 1 && $profileGlobalPermission[2] == 1 && $defaultOrgSharingPermission[7] == 3)
-		{
-			//Added security check to get the permitted records only
-			$query = $query." ".getListViewSecurityParameter($thismodule);
-		}
 		return $query;
 	}
 
@@ -253,7 +291,7 @@ class ModuleClass extends CRMEntity {
 	 * Initialize this instance for importing.
 	 */
 	function initImport($module) {
-		$this->db = new PearDatabase();
+		$this->db = PearDatabase::getInstance();
 		$this->initImportableFields($module);
 	}
 
@@ -263,14 +301,14 @@ class ModuleClass extends CRMEntity {
 	 */
 	function create_import_query($module) {
 		global $current_user;
-		$query = "SELECT vtiger_crmentity.crmid, vtiger_users.user_name, $this->table_name.* FROM $this->table_name
+		$query = "SELECT vtiger_crmentity.crmid, case when (vtiger_users.user_name not like '') then vtiger_users.user_name else vtiger_groups.groupname end as user_name, $this->table_name.* FROM $this->table_name
 			INNER JOIN vtiger_crmentity ON vtiger_crmentity.crmid = $this->table_name.$this->table_index
 			LEFT JOIN vtiger_users_last_import ON vtiger_users_last_import.bean_id=vtiger_crmentity.crmid
 			LEFT JOIN vtiger_users ON vtiger_users.id = vtiger_crmentity.smownerid
+			LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid
 			WHERE vtiger_users_last_import.assigned_user_id='$current_user->id'
 			AND vtiger_users_last_import.bean_type='$module'
-			AND vtiger_users_last_import.deleted=0
-			AND vtiger_users.status = 'Active'";
+			AND vtiger_users_last_import.deleted=0";
 		return $query;
 	}
 
@@ -290,14 +328,14 @@ class ModuleClass extends CRMEntity {
 		}
 		return $count;
 	}
-
+	
 	/**
-	 * Transform the value while exporting (if required)
+	 * Transform the value while exporting
 	 */
 	function transform_export_value($key, $value) {
 		return parent::transform_export_value($key, $value);
 	}
-	
+
 	/**
 	 * Function which will set the assigned user id for import record.
 	 */
@@ -307,7 +345,7 @@ class ModuleClass extends CRMEntity {
 		$record_user = $this->column_fields["assigned_user_id"];
 		
 		if($record_user != $current_user->id){
-			$sqlresult = $adb->pquery("select id from vtiger_users where id = ?", array($record_user));
+			$sqlresult = $adb->pquery("select id from vtiger_users where id = ? union select groupid as id from vtiger_groups where groupid = ?", array($record_user, $record_user));
 			if($this->db->num_rows($sqlresult)!= 1) {
 				$this->column_fields["assigned_user_id"] = $current_user->id;
 			} else {			
@@ -320,6 +358,52 @@ class ModuleClass extends CRMEntity {
 			}
 		}
 	}
+	
+	/** 
+	 * Function which will give the basic query to find duplicates
+	 */
+	function getDuplicatesQuery($module,$table_cols,$field_values,$ui_type_arr,$select_cols='') {
+		$select_clause = "SELECT ". $this->table_name .".".$this->table_index ." AS recordid, vtiger_users_last_import.deleted,".$table_cols;
+
+		// Select Custom Field Table Columns if present
+		if(isset($this->customFieldTable)) $query .= ", " . $this->customFieldTable[0] . ".* ";
+
+		$from_clause = " FROM $this->table_name";
+
+		$from_clause .= "	INNER JOIN vtiger_crmentity ON vtiger_crmentity.crmid = $this->table_name.$this->table_index";
+
+		// Consider custom table join as well.
+		if(isset($this->customFieldTable)) {
+			$from_clause .= " INNER JOIN ".$this->customFieldTable[0]." ON ".$this->customFieldTable[0].'.'.$this->customFieldTable[1] .
+				      " = $this->table_name.$this->table_index"; 
+		}
+		$from_clause .= " LEFT JOIN vtiger_users ON vtiger_users.id = vtiger_crmentity.smownerid
+						LEFT JOIN vtiger_groups ON vtiger_groups.groupid = vtiger_crmentity.smownerid";
+		
+		$where_clause = "	WHERE vtiger_crmentity.deleted = 0";
+		$where_clause .= $this->getListViewSecurityParameter($module);
+					
+		if (isset($select_cols) && trim($select_cols) != '') {
+			$sub_query = "SELECT $select_cols FROM  $this->table_name AS t " .
+				" INNER JOIN vtiger_crmentity AS crm ON crm.crmid = t.".$this->table_index;
+			// Consider custom table join as well.
+			if(isset($this->customFieldTable)) {
+				$sub_query .= " LEFT JOIN ".$this->customFieldTable[0]." tcf ON tcf.".$this->customFieldTable[1]." = t.$this->table_index";
+			}
+			$sub_query .= " WHERE crm.deleted=0 GROUP BY $select_cols HAVING COUNT(*)>1";	
+		} else {
+			$sub_query = "SELECT $table_cols $from_clause $where_clause GROUP BY $table_cols HAVING COUNT(*)>1";
+		}	
+		
+		
+		$query = $select_clause . $from_clause .
+					" LEFT JOIN vtiger_users_last_import ON vtiger_users_last_import.bean_id=" . $this->table_name .".".$this->table_index .
+					" INNER JOIN (" . $sub_query . ") AS temp ON ".get_on_clause($field_values,$ui_type_arr,$module) .
+					$where_clause .
+					" ORDER BY $table_cols,". $this->table_name .".".$this->table_index ." ASC";
+					
+		return $query;		
+	}
 
 	/**
 	 * Invoked when special actions are performed on the module.
@@ -341,7 +425,7 @@ class ModuleClass extends CRMEntity {
 			// TODO Handle actions after this module is updated.
 		}
 	}
-	
+
 	/** 
 	 * Handle saving related module information.
 	 * NOTE: This function has been added to CRMEntity (base class).
@@ -362,5 +446,12 @@ class ModuleClass extends CRMEntity {
 	 * You can override the behavior by re-defining it here.
 	 */
 	//function get_related_list($id, $cur_tab_id, $rel_tab_id, $actions=false) { }
+
+	/**
+	 * Handle getting dependents list information.
+	 * NOTE: This function has been added to CRMEntity (base class).
+	 * You can override the behavior by re-defining it here.
+	 */
+	//function get_dependents_list($id, $cur_tab_id, $rel_tab_id, $actions=false) { }
 }
-?>
\ No newline at end of file
+?>
